import { Writer, Reader } from "protobufjs";
import { Coder, Context, ProtoContext } from "./coders";
import { BoolCoder, StrUtf8Coder } from "./standard_coders";
import { IterableCoder } from "./required_coders";
import * as runnerApi from "../proto/beam_runner_api";
/**
 * A Coder<T> that encodes a javascript object with BSON.
 */
export declare class BsonObjectCoder<T> implements Coder<T> {
    static URN: string;
    encode(element: T, writer: Writer, context: Context): void;
    decode(reader: Reader, context: Context): T;
    toProto(pipelineContext: ProtoContext): runnerApi.Coder;
}
declare class NumberOrFloatCoder implements Coder<number> {
    static URN: string;
    intCoder: Coder<number>;
    doubleCoder: Coder<number>;
    encode(element: number, writer: Writer, context: Context): void;
    decode(reader: Reader, context: Context): number;
    toProto(pipelineContext: ProtoContext): runnerApi.Coder;
}
/**
 * A Coder<T> that encodes common javascript types such as strings, numbers,
 * nulls, or objects.
 */
export declare class GeneralObjectCoder<T> implements Coder<T> {
    static URN: string;
    codersByType: {
        string: StrUtf8Coder;
        number: NumberOrFloatCoder;
        object: BsonObjectCoder<unknown>;
        boolean: BoolCoder;
        array: IterableCoder<T>;
    };
    typeMarkers: {
        string: string;
        number: string;
        object: string;
        boolean: string;
        array: string;
    };
    markerToTypes: {
        S: string;
        N: string;
        O: string;
        B: string;
        A: string;
    };
    encode(element: T, writer: Writer, context: Context): void;
    decode(reader: Reader, context: Context): T;
    toProto(pipelineContext: ProtoContext): runnerApi.Coder;
}
export {};
