import * as runnerApi from "../proto/beam_runner_api";
import { Writer, Reader } from "protobufjs";
import { Coder, Context, ProtoContext } from "./coders";
import { Schema, Field, FieldType } from "../proto/schema";
interface LogicalTypeInfo<T, R> {
    urn: string;
    reprType: FieldType;
    toRepr(obj: T): R;
    fromRepr(repr: R): T;
}
export declare function registerLogicalType(logicalType: LogicalTypeInfo<any, any>): void;
/**
 * A coder for encoding Objects as row objects with a given schema.
 *
 * This is particularly useful for cross-language interoperability,
 * and is more efficient than the general object encoding scheme as the
 * fields (and their types) are fixed and do not have to be encoded along
 * with each individual element.
 *
 * While RowCoders can be instantiated directly from a schema object,
 * there is also the convenience method `RowCoder.fromJSON()` method that
 * can infer a RowCoder from a prototypical example, e.g.
 *
 *```js
 * const my_row_coder = RowCoder.fromJSON({int_field: 0, str_field: ""});
 *```
 */
export declare class RowCoder implements Coder<any> {
    static URN: string;
    private schema;
    private nFields;
    private fieldNames;
    private fieldNullable;
    private encodingPositionsAreTrivial;
    private encodingPositions;
    private encodingPositionsArgsSorted;
    private hasNullableFields;
    private components;
    addFieldOfType(obj: any, f: Field, value: any): any;
    static inferTypeFromJSON(obj: any, nullable?: boolean): FieldType;
    static inferSchemaOfJSON(obj: any): Schema;
    getCoderFromType(t: FieldType): any;
    getNonNullCoderFromType(t: FieldType): any;
    static fromSchema(schema: Schema): RowCoder;
    static fromJSON(obj: any): RowCoder;
    constructor(rawSchema: Schema | Uint8Array);
    encode(element: any, writer: Writer, context: Context): void;
    decode(reader: Reader, context: Context): any;
    toProto(pipelineContext: ProtoContext): runnerApi.Coder;
}
export {};
