import * as runnerApi from "../proto/beam_runner_api";
import * as fnApi from "../proto/beam_fn_api";
import { PTransformClass, AsyncPTransformClass } from "../transforms/transform";
import * as pvalue from "../pvalue";
import { Coder } from "../coders/coders";
declare type Components = runnerApi.Components | fnApi.ProcessBundleDescriptor;
export declare class PipelineContext {
    components: Components;
    private componentPrefix;
    counter: number;
    private coders;
    constructor(components: Components, componentPrefix: string);
    getCoder<T>(coderId: string): Coder<T>;
    getCoderId(coder: Coder<any>): string;
    getPCollectionCoder<T>(pcoll: pvalue.PCollection<T>): Coder<T>;
    getPCollectionCoderId<T>(pcoll: pvalue.PCollection<T>): string;
    getWindowingStrategy(id: string): runnerApi.WindowingStrategy;
    getWindowingStrategyId(windowing: runnerApi.WindowingStrategy): string;
    private getOrAssign;
    createUniqueName(prefix: string): string;
}
/**
 * A Pipeline holds the Beam DAG and auxiliary information needed to construct
 * Beam Pipelines.
 */
export declare class Pipeline {
    context: PipelineContext;
    transformStack: string[];
    defaultEnvironment: string;
    usedStageNames: Set<string>;
    private proto;
    private globalWindowing;
    constructor(componentPrefix?: string);
    preApplyTransform<InputT extends pvalue.PValue<any>, OutputT extends pvalue.PValue<any>>(transform: AsyncPTransformClass<InputT, OutputT>, input: InputT): {
        id: string;
        proto: runnerApi.PTransform;
    };
    applyTransform<InputT extends pvalue.PValue<any>, OutputT extends pvalue.PValue<any>>(transform: PTransformClass<InputT, OutputT>, input: InputT): OutputT;
    applyAsyncTransform<InputT extends pvalue.PValue<any>, OutputT extends pvalue.PValue<any>>(transform: AsyncPTransformClass<InputT, OutputT>, input: InputT): Promise<OutputT>;
    postApplyTransform<InputT extends pvalue.PValue<any>, OutputT extends pvalue.PValue<any>>(transform: AsyncPTransformClass<InputT, OutputT>, transformProto: runnerApi.PTransform, result: OutputT): OutputT;
    createPCollectionInternal<OutputT>(coder: Coder<OutputT> | string, windowingStrategy?: runnerApi.WindowingStrategy | string | undefined, isBounded?: runnerApi.IsBounded_Enum | undefined): pvalue.PCollection<OutputT>;
    createPCollectionIdInternal<OutputT>(coder: Coder<OutputT> | string, windowingStrategy?: runnerApi.WindowingStrategy | string | undefined, isBounded?: runnerApi.IsBounded_Enum | undefined): string;
    getCoder<T>(coderId: string): Coder<T>;
    getCoderId(coder: Coder<any>): string;
    getProto(): runnerApi.Pipeline;
}
export {};
