import type { RpcTransport } from "@protobuf-ts/runtime-rpc";
import type { ServiceInfo } from "@protobuf-ts/runtime-rpc";
import type { DescribePipelineOptionsResponse } from "./beam_job_api";
import type { DescribePipelineOptionsRequest } from "./beam_job_api";
import type { GetJobMetricsResponse } from "./beam_job_api";
import type { GetJobMetricsRequest } from "./beam_job_api";
import type { JobMessagesResponse } from "./beam_job_api";
import type { JobMessagesRequest } from "./beam_job_api";
import type { ServerStreamingCall } from "@protobuf-ts/runtime-rpc";
import type { CancelJobResponse } from "./beam_job_api";
import type { CancelJobRequest } from "./beam_job_api";
import type { GetJobPipelineResponse } from "./beam_job_api";
import type { GetJobPipelineRequest } from "./beam_job_api";
import type { JobStateEvent } from "./beam_job_api";
import type { GetJobStateRequest } from "./beam_job_api";
import type { GetJobsResponse } from "./beam_job_api";
import type { GetJobsRequest } from "./beam_job_api";
import type { RunJobResponse } from "./beam_job_api";
import type { RunJobRequest } from "./beam_job_api";
import type { PrepareJobResponse } from "./beam_job_api";
import type { PrepareJobRequest } from "./beam_job_api";
import type { UnaryCall } from "@protobuf-ts/runtime-rpc";
import type { RpcOptions } from "@protobuf-ts/runtime-rpc";
/**
 * Job Service for running RunnerAPI pipelines
 *
 * @generated from protobuf service org.apache.beam.model.job_management.v1.JobService
 */
export interface IJobServiceClient {
    /**
     * Prepare a job for execution. The job will not be executed until a call is made to run with the
     * returned preparationId.
     *
     * @generated from protobuf rpc: Prepare(org.apache.beam.model.job_management.v1.PrepareJobRequest) returns (org.apache.beam.model.job_management.v1.PrepareJobResponse);
     */
    prepare(input: PrepareJobRequest, options?: RpcOptions): UnaryCall<PrepareJobRequest, PrepareJobResponse>;
    /**
     * Submit the job for execution
     *
     * @generated from protobuf rpc: Run(org.apache.beam.model.job_management.v1.RunJobRequest) returns (org.apache.beam.model.job_management.v1.RunJobResponse);
     */
    run(input: RunJobRequest, options?: RpcOptions): UnaryCall<RunJobRequest, RunJobResponse>;
    /**
     * Get a list of all invoked jobs
     *
     * @generated from protobuf rpc: GetJobs(org.apache.beam.model.job_management.v1.GetJobsRequest) returns (org.apache.beam.model.job_management.v1.GetJobsResponse);
     */
    getJobs(input: GetJobsRequest, options?: RpcOptions): UnaryCall<GetJobsRequest, GetJobsResponse>;
    /**
     * Get the current state of the job
     *
     * @generated from protobuf rpc: GetState(org.apache.beam.model.job_management.v1.GetJobStateRequest) returns (org.apache.beam.model.job_management.v1.JobStateEvent);
     */
    getState(input: GetJobStateRequest, options?: RpcOptions): UnaryCall<GetJobStateRequest, JobStateEvent>;
    /**
     * Get the job's pipeline
     *
     * @generated from protobuf rpc: GetPipeline(org.apache.beam.model.job_management.v1.GetJobPipelineRequest) returns (org.apache.beam.model.job_management.v1.GetJobPipelineResponse);
     */
    getPipeline(input: GetJobPipelineRequest, options?: RpcOptions): UnaryCall<GetJobPipelineRequest, GetJobPipelineResponse>;
    /**
     * Cancel the job
     *
     * @generated from protobuf rpc: Cancel(org.apache.beam.model.job_management.v1.CancelJobRequest) returns (org.apache.beam.model.job_management.v1.CancelJobResponse);
     */
    cancel(input: CancelJobRequest, options?: RpcOptions): UnaryCall<CancelJobRequest, CancelJobResponse>;
    /**
     * Subscribe to a stream of state changes of the job, will immediately return the current state of the job as the first response.
     *
     * @generated from protobuf rpc: GetStateStream(org.apache.beam.model.job_management.v1.GetJobStateRequest) returns (stream org.apache.beam.model.job_management.v1.JobStateEvent);
     */
    getStateStream(input: GetJobStateRequest, options?: RpcOptions): ServerStreamingCall<GetJobStateRequest, JobStateEvent>;
    /**
     * Subscribe to a stream of state changes and messages from the job
     *
     * @generated from protobuf rpc: GetMessageStream(org.apache.beam.model.job_management.v1.JobMessagesRequest) returns (stream org.apache.beam.model.job_management.v1.JobMessagesResponse);
     */
    getMessageStream(input: JobMessagesRequest, options?: RpcOptions): ServerStreamingCall<JobMessagesRequest, JobMessagesResponse>;
    /**
     * Fetch metrics for a given job
     *
     * @generated from protobuf rpc: GetJobMetrics(org.apache.beam.model.job_management.v1.GetJobMetricsRequest) returns (org.apache.beam.model.job_management.v1.GetJobMetricsResponse);
     */
    getJobMetrics(input: GetJobMetricsRequest, options?: RpcOptions): UnaryCall<GetJobMetricsRequest, GetJobMetricsResponse>;
    /**
     * Get the supported pipeline options of the runner
     *
     * @generated from protobuf rpc: DescribePipelineOptions(org.apache.beam.model.job_management.v1.DescribePipelineOptionsRequest) returns (org.apache.beam.model.job_management.v1.DescribePipelineOptionsResponse);
     */
    describePipelineOptions(input: DescribePipelineOptionsRequest, options?: RpcOptions): UnaryCall<DescribePipelineOptionsRequest, DescribePipelineOptionsResponse>;
}
/**
 * Job Service for running RunnerAPI pipelines
 *
 * @generated from protobuf service org.apache.beam.model.job_management.v1.JobService
 */
export declare class JobServiceClient implements IJobServiceClient, ServiceInfo {
    private readonly _transport;
    typeName: string;
    methods: import("@protobuf-ts/runtime-rpc").MethodInfo<any, any>[];
    options: {
        [extensionName: string]: import("@protobuf-ts/runtime").JsonValue;
    };
    constructor(_transport: RpcTransport);
    /**
     * Prepare a job for execution. The job will not be executed until a call is made to run with the
     * returned preparationId.
     *
     * @generated from protobuf rpc: Prepare(org.apache.beam.model.job_management.v1.PrepareJobRequest) returns (org.apache.beam.model.job_management.v1.PrepareJobResponse);
     */
    prepare(input: PrepareJobRequest, options?: RpcOptions): UnaryCall<PrepareJobRequest, PrepareJobResponse>;
    /**
     * Submit the job for execution
     *
     * @generated from protobuf rpc: Run(org.apache.beam.model.job_management.v1.RunJobRequest) returns (org.apache.beam.model.job_management.v1.RunJobResponse);
     */
    run(input: RunJobRequest, options?: RpcOptions): UnaryCall<RunJobRequest, RunJobResponse>;
    /**
     * Get a list of all invoked jobs
     *
     * @generated from protobuf rpc: GetJobs(org.apache.beam.model.job_management.v1.GetJobsRequest) returns (org.apache.beam.model.job_management.v1.GetJobsResponse);
     */
    getJobs(input: GetJobsRequest, options?: RpcOptions): UnaryCall<GetJobsRequest, GetJobsResponse>;
    /**
     * Get the current state of the job
     *
     * @generated from protobuf rpc: GetState(org.apache.beam.model.job_management.v1.GetJobStateRequest) returns (org.apache.beam.model.job_management.v1.JobStateEvent);
     */
    getState(input: GetJobStateRequest, options?: RpcOptions): UnaryCall<GetJobStateRequest, JobStateEvent>;
    /**
     * Get the job's pipeline
     *
     * @generated from protobuf rpc: GetPipeline(org.apache.beam.model.job_management.v1.GetJobPipelineRequest) returns (org.apache.beam.model.job_management.v1.GetJobPipelineResponse);
     */
    getPipeline(input: GetJobPipelineRequest, options?: RpcOptions): UnaryCall<GetJobPipelineRequest, GetJobPipelineResponse>;
    /**
     * Cancel the job
     *
     * @generated from protobuf rpc: Cancel(org.apache.beam.model.job_management.v1.CancelJobRequest) returns (org.apache.beam.model.job_management.v1.CancelJobResponse);
     */
    cancel(input: CancelJobRequest, options?: RpcOptions): UnaryCall<CancelJobRequest, CancelJobResponse>;
    /**
     * Subscribe to a stream of state changes of the job, will immediately return the current state of the job as the first response.
     *
     * @generated from protobuf rpc: GetStateStream(org.apache.beam.model.job_management.v1.GetJobStateRequest) returns (stream org.apache.beam.model.job_management.v1.JobStateEvent);
     */
    getStateStream(input: GetJobStateRequest, options?: RpcOptions): ServerStreamingCall<GetJobStateRequest, JobStateEvent>;
    /**
     * Subscribe to a stream of state changes and messages from the job
     *
     * @generated from protobuf rpc: GetMessageStream(org.apache.beam.model.job_management.v1.JobMessagesRequest) returns (stream org.apache.beam.model.job_management.v1.JobMessagesResponse);
     */
    getMessageStream(input: JobMessagesRequest, options?: RpcOptions): ServerStreamingCall<JobMessagesRequest, JobMessagesResponse>;
    /**
     * Fetch metrics for a given job
     *
     * @generated from protobuf rpc: GetJobMetrics(org.apache.beam.model.job_management.v1.GetJobMetricsRequest) returns (org.apache.beam.model.job_management.v1.GetJobMetricsResponse);
     */
    getJobMetrics(input: GetJobMetricsRequest, options?: RpcOptions): UnaryCall<GetJobMetricsRequest, GetJobMetricsResponse>;
    /**
     * Get the supported pipeline options of the runner
     *
     * @generated from protobuf rpc: DescribePipelineOptions(org.apache.beam.model.job_management.v1.DescribePipelineOptionsRequest) returns (org.apache.beam.model.job_management.v1.DescribePipelineOptionsResponse);
     */
    describePipelineOptions(input: DescribePipelineOptionsRequest, options?: RpcOptions): UnaryCall<DescribePipelineOptionsRequest, DescribePipelineOptionsResponse>;
}
