import { ServiceType } from "@protobuf-ts/runtime-rpc";
import type { BinaryWriteOptions } from "@protobuf-ts/runtime";
import type { IBinaryWriter } from "@protobuf-ts/runtime";
import type { BinaryReadOptions } from "@protobuf-ts/runtime";
import type { IBinaryReader } from "@protobuf-ts/runtime";
import type { PartialMessage } from "@protobuf-ts/runtime";
import { MessageType } from "@protobuf-ts/runtime";
import { ApiServiceDescriptor } from "./endpoints";
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.BeamConstants
 */
export interface BeamConstants {
}
/**
 * All timestamps in milliseconds since Jan 1, 1970.
 *
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.BeamConstants.Constants
 */
export declare enum BeamConstants_Constants {
    /**
     * All timestamps of elements or window boundaries must be within
     * the interval [MIN_TIMESTAMP_MILLIS, MAX_TIMESTAMP_MILLIS].
     * The smallest representable timestamp of an element or a window boundary.
     *
     * @generated from protobuf enum value: MIN_TIMESTAMP_MILLIS = 0;
     */
    MIN_TIMESTAMP_MILLIS = 0,
    /**
     * The largest representable timestamp of an element or a window boundary.
     *
     * @generated from protobuf enum value: MAX_TIMESTAMP_MILLIS = 1;
     */
    MAX_TIMESTAMP_MILLIS = 1,
    /**
     * The maximum timestamp for the global window.
     * Triggers use max timestamp to set timers' timestamp. Timers fire when
     * the watermark passes their timestamps. So, the timestamp needs to be
     * smaller than the MAX_TIMESTAMP_MILLIS.
     * One standard day is subtracted from MAX_TIMESTAMP_MILLIS to make sure
     * the max timestamp is smaller than MAX_TIMESTAMP_MILLIS even after rounding up
     * to seconds or minutes.
     *
     * @generated from protobuf enum value: GLOBAL_WINDOW_MAX_TIMESTAMP_MILLIS = 2;
     */
    GLOBAL_WINDOW_MAX_TIMESTAMP_MILLIS = 2
}
/**
 * A set of mappings from id to message. This is included as an optional field
 * on any proto message that may contain references needing resolution.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.Components
 */
export interface Components {
    /**
     * (Required) A map from pipeline-scoped id to PTransform.
     *
     * Keys of the transforms map may be used by runners to identify pipeline
     * steps. Hence it's recommended to use strings that are not too long that
     * match regex '[A-Za-z0-9-_]+'.
     *
     * @generated from protobuf field: map<string, org.apache.beam.model.pipeline.v1.PTransform> transforms = 1;
     */
    transforms: {
        [key: string]: PTransform;
    };
    /**
     * (Required) A map from pipeline-scoped id to PCollection.
     *
     * @generated from protobuf field: map<string, org.apache.beam.model.pipeline.v1.PCollection> pcollections = 2;
     */
    pcollections: {
        [key: string]: PCollection;
    };
    /**
     * (Required) A map from pipeline-scoped id to WindowingStrategy.
     *
     * @generated from protobuf field: map<string, org.apache.beam.model.pipeline.v1.WindowingStrategy> windowing_strategies = 3;
     */
    windowingStrategies: {
        [key: string]: WindowingStrategy;
    };
    /**
     * (Required) A map from pipeline-scoped id to Coder.
     *
     * @generated from protobuf field: map<string, org.apache.beam.model.pipeline.v1.Coder> coders = 4;
     */
    coders: {
        [key: string]: Coder;
    };
    /**
     * (Required) A map from pipeline-scoped id to Environment.
     *
     * @generated from protobuf field: map<string, org.apache.beam.model.pipeline.v1.Environment> environments = 5;
     */
    environments: {
        [key: string]: Environment;
    };
}
/**
 * A Pipeline is a hierarchical graph of PTransforms, linked
 * by PCollections. A typical graph may look like:
 *
 *   Impulse -> PCollection -> ParDo -> PCollection -> GroupByKey -> ...
 *                                   \> PCollection -> ParDo      -> ...
 *                                                  \> ParDo      -> ...
 *   Impulse -> PCollection -> ParDo -> PCollection -> ...
 *
 * This is represented by a number of by-reference maps to transforms,
 * PCollections, SDK environments, coders, etc., for
 * supporting compact reuse and arbitrary graph structure.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.Pipeline
 */
export interface Pipeline {
    /**
     * (Required) The coders, UDFs, graph nodes, etc, that make up
     * this pipeline.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Components components = 1;
     */
    components?: Components;
    /**
     * (Required) The ids of all PTransforms that are not contained within another
     * PTransform. These must be in shallow topological order, so that traversing
     * them recursively in this order yields a recursively topological traversal.
     *
     * @generated from protobuf field: repeated string root_transform_ids = 2;
     */
    rootTransformIds: string[];
    /**
     * (Optional) Static display data for the pipeline. If there is none,
     * it may be omitted.
     *
     * @generated from protobuf field: repeated org.apache.beam.model.pipeline.v1.DisplayData display_data = 3;
     */
    displayData: DisplayData[];
    /**
     * (Optional) A set of requirements that the runner MUST understand and be
     * able to faithfully provide in order to execute this pipeline. These
     * may indicate that a runner must inspect new fields on a component or
     * provide additional guarantees when processing specific transforms.
     * A runner should reject any pipelines with unknown requirements.
     *
     * @generated from protobuf field: repeated string requirements = 4;
     */
    requirements: string[];
}
/**
 * Transforms are the operations in your pipeline, and provide a generic
 * processing framework. You provide processing logic in the form of a function
 * object (colloquially referred to as “user code”), and your user code is
 * applied to each element of an input PCollection (or more than one
 * PCollection). Depending on the pipeline runner and back-end that you choose,
 * many different workers across a cluster may execute instances of your user
 * code in parallel. The user code running on each worker generates the output
 * elements that are ultimately added to the final output PCollection that the
 * transform produces.
 *
 * The Beam SDKs contain a number of different transforms that you can apply to
 * your pipeline’s PCollections. These include general-purpose core transforms,
 * such as ParDo or Combine. There are also pre-written composite transforms
 * included in the SDKs, which combine one or more of the core transforms in a
 * useful processing pattern, such as counting or combining elements in a
 * collection. You can also define your own more complex composite transforms to
 * fit your pipeline’s exact use case.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.PTransform
 */
export interface PTransform {
    /**
     * (Required) A unique name for the application node.
     *
     * Ideally, this should be stable over multiple evolutions of a pipeline
     * for the purposes of logging and associating pipeline state with a node,
     * etc.
     *
     * If it is not stable, then the runner decides what will happen. But, most
     * importantly, it must always be here and be unique, even if it is
     * autogenerated.
     *
     * @generated from protobuf field: string unique_name = 5;
     */
    uniqueName: string;
    /**
     * (Optional) A URN and payload that, together, fully defined the semantics
     * of this transform.
     *
     * If absent, this must be an "anonymous" composite transform.
     *
     * For primitive transform in the Runner API, this is required, and the
     * payloads are well-defined messages. When the URN indicates ParDo it
     * is a ParDoPayload, and so on. For some special composite transforms,
     * the payload is also officially defined. See StandardPTransforms for
     * details.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.FunctionSpec spec = 1;
     */
    spec?: FunctionSpec;
    /**
     * (Optional) A list of the ids of transforms that it contains.
     *
     * Primitive transforms (see StandardPTransforms.Primitives) are not allowed
     * to specify subtransforms.
     *
     * Note that a composite transform may have zero subtransforms as long as it
     * only outputs PCollections that are in its inputs.
     *
     * @generated from protobuf field: repeated string subtransforms = 2;
     */
    subtransforms: string[];
    /**
     * (Required) A map from local names of inputs (unique only with this map, and
     * likely embedded in the transform payload and serialized user code) to
     * PCollection ids.
     *
     * The payload for this transform may clarify the relationship of these
     * inputs. For example:
     *
     *  - for a Flatten transform they are merged
     *  - for a ParDo transform, some may be side inputs
     *
     * All inputs are recorded here so that the topological ordering of
     * the graph is consistent whether or not the payload is understood.
     *
     * @generated from protobuf field: map<string, string> inputs = 3;
     */
    inputs: {
        [key: string]: string;
    };
    /**
     * (Required) A map from local names of outputs (unique only within this map,
     * and likely embedded in the transform payload and serialized user code)
     * to PCollection ids.
     *
     * The URN or payload for this transform node may clarify the type and
     * relationship of these outputs. For example:
     *
     *  - for a ParDo transform, these are tags on PCollections, which will be
     *    embedded in the DoFn.
     *
     * @generated from protobuf field: map<string, string> outputs = 4;
     */
    outputs: {
        [key: string]: string;
    };
    /**
     * (Optional) Static display data for this PTransform application. If
     * there is none, it may be omitted.
     *
     * @generated from protobuf field: repeated org.apache.beam.model.pipeline.v1.DisplayData display_data = 6;
     */
    displayData: DisplayData[];
    /**
     * Environment where the current PTransform should be executed in.
     *
     * Transforms that are required to be implemented by a runner must omit this.
     * All other transforms are required to specify this.
     *
     * @generated from protobuf field: string environment_id = 7;
     */
    environmentId: string;
    /**
     * (Optional) A map from URNs designating a type of annotation, to the
     * annotation in binary format. For example, an annotation could indicate
     * that this PTransform has specific privacy properties.
     *
     * A runner MAY ignore types of annotations it doesn't understand. Therefore
     * annotations MUST NOT be used for metadata that can affect correct
     * execution of the transform.
     *
     * @generated from protobuf field: map<string, bytes> annotations = 8;
     */
    annotations: {
        [key: string]: Uint8Array;
    };
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.StandardPTransforms
 */
export interface StandardPTransforms {
}
/**
 * Primitive transforms may not specify composite sub-transforms.
 *
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.StandardPTransforms.Primitives
 */
export declare enum StandardPTransforms_Primitives {
    /**
     * ParDo is a Beam transform for generic parallel processing. The ParDo
     * processing paradigm is similar to the “Map” phase of a
     * Map/Shuffle/Reduce-style algorithm: a ParDo transform considers each
     * element in the input PCollection, performs some processing function
     * (your user code) on that element, and emits zero, one, or multiple
     * elements to an output PCollection.
     *
     * See https://beam.apache.org/documentation/programming-guide/#pardo
     * for additional details.
     *
     * Payload: ParDoPayload
     *
     * @generated from protobuf enum value: PAR_DO = 0;
     */
    PAR_DO = 0,
    /**
     * Flatten is a Beam transform for PCollection objects that store the same
     * data type. Flatten merges multiple PCollection objects into a single
     * logical PCollection.
     *
     * See https://beam.apache.org/documentation/programming-guide/#flatten
     * for additional details.
     *
     * Payload: None
     *
     * @generated from protobuf enum value: FLATTEN = 1;
     */
    FLATTEN = 1,
    /**
     * GroupByKey is a Beam transform for processing collections of key/value
     * pairs. It’s a parallel reduction operation, analogous to the Shuffle
     * phase of a Map/Shuffle/Reduce-style algorithm. The input to GroupByKey is
     * a collection of key/value pairs that represents a multimap, where the
     * collection contains multiple pairs that have the same key, but different
     * values. Given such a collection, you use GroupByKey to collect all of the
     * values associated with each unique key.
     *
     * See https://beam.apache.org/documentation/programming-guide/#groupbykey
     * for additional details.
     *
     * Never defines an environment as the runner is required to implement this
     * transform.
     *
     * Payload: None
     *
     * @generated from protobuf enum value: GROUP_BY_KEY = 2;
     */
    GROUP_BY_KEY = 2,
    /**
     * A transform which produces a single empty byte array at the minimum
     * timestamp in the GlobalWindow.
     *
     * Never defines an environment as the runner is required to implement this
     * transform.
     *
     * Payload: None
     *
     * @generated from protobuf enum value: IMPULSE = 3;
     */
    IMPULSE = 3,
    /**
     * Windowing subdivides a PCollection according to the timestamps of its
     * individual elements. Transforms that aggregate multiple elements, such as
     * GroupByKey and Combine, work implicitly on a per-window basis — they
     * process each PCollection as a succession of multiple, finite windows,
     * though the entire collection itself may be of unbounded size.
     *
     * See https://beam.apache.org/documentation/programming-guide/#windowing
     * for additional details.
     *
     * Payload: WindowIntoPayload
     *
     * @generated from protobuf enum value: ASSIGN_WINDOWS = 4;
     */
    ASSIGN_WINDOWS = 4,
    /**
     * A testing input that generates an unbounded {@link PCollection} of
     * elements, advancing the watermark and processing time as elements are
     * emitted. After all of the specified elements are emitted, ceases to
     * produce output.
     *
     * See https://beam.apache.org/blog/2016/10/20/test-stream.html
     * for additional details.
     *
     * Payload: TestStreamPayload
     *
     * @generated from protobuf enum value: TEST_STREAM = 5;
     */
    TEST_STREAM = 5,
    /**
     * Represents mapping of main input window onto side input window.
     *
     * Side input window mapping function:
     * Input: KV<nonce, MainInputWindow>
     * Output: KV<nonce, SideInputWindow>
     *
     * For each main input window, the side input window is returned. The
     * nonce is used by a runner to associate each input with its output.
     * The nonce is represented as an opaque set of bytes.
     *
     * Payload: SideInput#window_mapping_fn FunctionSpec
     *
     * @generated from protobuf enum value: MAP_WINDOWS = 6;
     */
    MAP_WINDOWS = 6,
    /**
     * Used to merge windows during a GroupByKey.
     *
     * Window merging function:
     * Input: KV<nonce, iterable<OriginalWindow>>
     * Output: KV<nonce, KV<iterable<UnmergedOriginalWindow>, iterable<KV<MergedWindow, iterable<ConsumedOriginalWindow>>>>
     *
     * For each set of original windows, a list of all unmerged windows is
     * output alongside a map of merged window to set of consumed windows.
     * All original windows must be contained in either the unmerged original
     * window set or one of the consumed original window sets. Each original
     * window can only be part of one output set. The nonce is used by a runner
     * to associate each input with its output. The nonce is represented as an
     * opaque set of bytes.
     *
     * Payload: WindowingStrategy#window_fn FunctionSpec
     *
     * @generated from protobuf enum value: MERGE_WINDOWS = 7;
     */
    MERGE_WINDOWS = 7,
    /**
     * A transform that translates a given element to its human-readable
     * representation.
     *
     * Input: KV<nonce, element>
     * Output: KV<nonce, string>
     *
     * For each given element, the implementation returns the best-effort
     * human-readable representation. When possible, the implementation could
     * call a user-overridable method on the type. For example, Java could
     * call `toString()`, Python could call `str()`, Golang could call
     * `String()`.  The nonce is used by a runner to associate each input with
     * its output. The nonce is represented as an opaque set of bytes.
     *
     * Payload: none
     *
     * @generated from protobuf enum value: TO_STRING = 8;
     */
    TO_STRING = 8
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.StandardPTransforms.DeprecatedPrimitives
 */
export declare enum StandardPTransforms_DeprecatedPrimitives {
    /**
     * Represents the operation to read a Bounded or Unbounded source.
     * Payload: ReadPayload.
     *
     * @generated from protobuf enum value: READ = 0;
     */
    READ = 0,
    /**
     * Runners should move away from translating `CreatePCollectionView` and treat this as
     * part of the translation for a `ParDo` side input.
     *
     * @generated from protobuf enum value: CREATE_VIEW = 1;
     */
    CREATE_VIEW = 1
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.StandardPTransforms.Composites
 */
export declare enum StandardPTransforms_Composites {
    /**
     * Represents the Combine.perKey() operation.
     * If this is produced by an SDK, it is assumed that the SDK understands
     * each of CombineComponents.
     * Payload: CombinePayload
     *
     * @generated from protobuf enum value: COMBINE_PER_KEY = 0;
     */
    COMBINE_PER_KEY = 0,
    /**
     * Represents the Combine.globally() operation.
     * If this is produced by an SDK, it is assumed that the SDK understands
     * each of CombineComponents.
     * Payload: CombinePayload
     *
     * @generated from protobuf enum value: COMBINE_GLOBALLY = 1;
     */
    COMBINE_GLOBALLY = 1,
    /**
     * Represents the Reshuffle operation.
     *
     * @generated from protobuf enum value: RESHUFFLE = 2;
     */
    RESHUFFLE = 2,
    /**
     * Less well-known. Payload: WriteFilesPayload.
     *
     * @generated from protobuf enum value: WRITE_FILES = 3;
     */
    WRITE_FILES = 3,
    /**
     * Payload: PubSubReadPayload.
     *
     * @generated from protobuf enum value: PUBSUB_READ = 4;
     */
    PUBSUB_READ = 4,
    /**
     * Payload: PubSubWritePayload.
     *
     * @generated from protobuf enum value: PUBSUB_WRITE = 5;
     */
    PUBSUB_WRITE = 5,
    /**
     * Used for pubsub dynamic destinations.
     * Payload: PubSubWritePayload.
     *
     * @generated from protobuf enum value: PUBSUB_WRITE_V2 = 7;
     */
    PUBSUB_WRITE_V2 = 7,
    /**
     * Represents the GroupIntoBatches.WithShardedKey operation.
     * Payload: GroupIntoBatchesPayload
     *
     * @generated from protobuf enum value: GROUP_INTO_BATCHES_WITH_SHARDED_KEY = 6;
     */
    GROUP_INTO_BATCHES_WITH_SHARDED_KEY = 6
}
/**
 * Payload for all of these: CombinePayload
 *
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.StandardPTransforms.CombineComponents
 */
export declare enum StandardPTransforms_CombineComponents {
    /**
     * Represents the Pre-Combine part of a lifted Combine Per Key, as described
     * in the following document:
     * https://s.apache.org/beam-runner-api-combine-model#heading=h.ta0g6ase8z07
     * Payload: CombinePayload
     *
     * @generated from protobuf enum value: COMBINE_PER_KEY_PRECOMBINE = 0;
     */
    COMBINE_PER_KEY_PRECOMBINE = 0,
    /**
     * Represents the Merge Accumulators part of a lifted Combine Per Key, as
     * described in the following document:
     * https://s.apache.org/beam-runner-api-combine-model#heading=h.jco9rvatld5m
     * Payload: CombinePayload
     *
     * @generated from protobuf enum value: COMBINE_PER_KEY_MERGE_ACCUMULATORS = 1;
     */
    COMBINE_PER_KEY_MERGE_ACCUMULATORS = 1,
    /**
     * Represents the Extract Outputs part of a lifted Combine Per Key, as
     * described in the following document:
     * https://s.apache.org/beam-runner-api-combine-model#heading=h.i9i6p8gtl6ku
     * Payload: CombinePayload
     *
     * @generated from protobuf enum value: COMBINE_PER_KEY_EXTRACT_OUTPUTS = 2;
     */
    COMBINE_PER_KEY_EXTRACT_OUTPUTS = 2,
    /**
     * Represents the Combine Grouped Values transform, as described in the
     * following document:
     * https://s.apache.org/beam-runner-api-combine-model#heading=h.aj86ew4v1wk
     * Payload: CombinePayload
     *
     * @generated from protobuf enum value: COMBINE_GROUPED_VALUES = 3;
     */
    COMBINE_GROUPED_VALUES = 3,
    /**
     * Represents the Convert To Accumulators transform, as described in the
     * following document:
     * https://s.apache.org/beam-runner-api-combine-model#heading=h.h5697l1scd9x
     * Payload: CombinePayload
     *
     * @generated from protobuf enum value: COMBINE_PER_KEY_CONVERT_TO_ACCUMULATORS = 4;
     */
    COMBINE_PER_KEY_CONVERT_TO_ACCUMULATORS = 4
}
/**
 * Payload for all of these: ParDoPayload containing the user's SDF
 *
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.StandardPTransforms.SplittableParDoComponents
 */
export declare enum StandardPTransforms_SplittableParDoComponents {
    /**
     * Pairs the input element with its initial restriction.
     * Input: element; output: KV(element, restriction).
     *
     * @generated from protobuf enum value: PAIR_WITH_RESTRICTION = 0;
     */
    PAIR_WITH_RESTRICTION = 0,
    /**
     * Splits the restriction of each element/restriction pair and returns the
     * resulting splits, with a corresponding floating point size estimation
     * for each.
     *
     * A reasonable value for size is the number of bytes expected to be
     * produced by this (element, restriction) pair.
     *
     * Input: KV(element, restriction)
     * Output: KV(KV(element, restriction), size))
     *
     * @generated from protobuf enum value: SPLIT_AND_SIZE_RESTRICTIONS = 1;
     */
    SPLIT_AND_SIZE_RESTRICTIONS = 1,
    /**
     * Applies the DoFn to every element and restriction.
     *
     * All primary and residuals returned from checkpointing or splitting must
     * have the same type as the input to this transform.
     *
     * Input: KV(KV(element, restriction), size); output: DoFn's output.
     *
     * @generated from protobuf enum value: PROCESS_SIZED_ELEMENTS_AND_RESTRICTIONS = 2;
     */
    PROCESS_SIZED_ELEMENTS_AND_RESTRICTIONS = 2,
    /**
     * Truncates the restriction of each element/restriction pair and returns
     * the finite restriction which will be processed when a pipeline is
     * drained. See
     * https://docs.google.com/document/d/1NExwHlj-2q2WUGhSO4jTu8XGhDPmm3cllSN8IMmWci8/edit#.
     * for additional details about drain.
     *
     * Input: KV(KV(element, restriction), size);
     * Output: KV(KV(element, restriction), size).
     *
     * @generated from protobuf enum value: TRUNCATE_SIZED_RESTRICTION = 3;
     */
    TRUNCATE_SIZED_RESTRICTION = 3
}
/**
 * Payload for all of these: GroupIntoBatchesPayload
 *
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.StandardPTransforms.GroupIntoBatchesComponents
 */
export declare enum StandardPTransforms_GroupIntoBatchesComponents {
    /**
     * @generated from protobuf enum value: GROUP_INTO_BATCHES = 0;
     */
    GROUP_INTO_BATCHES = 0
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.StandardSideInputTypes
 */
export interface StandardSideInputTypes {
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.StandardSideInputTypes.Enum
 */
export declare enum StandardSideInputTypes_Enum {
    /**
     * Represents a view over a PCollection<V>.
     *
     * StateGetRequests performed on this side input must use
     * StateKey.IterableSideInput.
     *
     * @generated from protobuf enum value: ITERABLE = 0;
     */
    ITERABLE = 0,
    /**
     * Represents a view over a PCollection<KV<K, V>>.
     *
     * StateGetRequests performed on this side input must use
     * StateKey.MultimapKeysSideInput or StateKey.MultimapSideInput.
     *
     * @generated from protobuf enum value: MULTIMAP = 1;
     */
    MULTIMAP = 1
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.StandardUserStateTypes
 */
export interface StandardUserStateTypes {
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.StandardUserStateTypes.Enum
 */
export declare enum StandardUserStateTypes_Enum {
    /**
     * Represents a user state specification that supports a bag.
     *
     * StateRequests performed on this user state must use
     * StateKey.BagUserState.
     *
     * @generated from protobuf enum value: BAG = 0;
     */
    BAG = 0,
    /**
     * Represents a user state specification that supports a multimap.
     *
     * StateRequests performed on this user state must use
     * StateKey.MultimapKeysUserState or StateKey.MultimapUserState.
     *
     * @generated from protobuf enum value: MULTIMAP = 1;
     */
    MULTIMAP = 1
}
/**
 * A PCollection!
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.PCollection
 */
export interface PCollection {
    /**
     * (Required) A unique name for the PCollection.
     *
     * Ideally, this should be stable over multiple evolutions of a pipeline
     * for the purposes of logging and associating pipeline state with a node,
     * etc.
     *
     * If it is not stable, then the runner decides what will happen. But, most
     * importantly, it must always be here, even if it is autogenerated.
     *
     * @generated from protobuf field: string unique_name = 1;
     */
    uniqueName: string;
    /**
     * (Required) The id of the Coder for this PCollection.
     *
     * @generated from protobuf field: string coder_id = 2;
     */
    coderId: string;
    /**
     * (Required) Whether this PCollection is bounded or unbounded
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.IsBounded.Enum is_bounded = 3;
     */
    isBounded: IsBounded_Enum;
    /**
     * (Required) The id of the windowing strategy for this PCollection.
     *
     * @generated from protobuf field: string windowing_strategy_id = 4;
     */
    windowingStrategyId: string;
    /**
     * (Optional) Static display data for the PCollection. If there is none,
     * it may be omitted.
     *
     * @generated from protobuf field: repeated org.apache.beam.model.pipeline.v1.DisplayData display_data = 5;
     */
    displayData: DisplayData[];
}
/**
 * The payload for the primitive ParDo transform.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.ParDoPayload
 */
export interface ParDoPayload {
    /**
     * (Required) The FunctionSpec of the DoFn.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.FunctionSpec do_fn = 1;
     */
    doFn?: FunctionSpec;
    /**
     * (Optional) A mapping of local input names to side inputs, describing
     * the expected access pattern.
     *
     * @generated from protobuf field: map<string, org.apache.beam.model.pipeline.v1.SideInput> side_inputs = 3;
     */
    sideInputs: {
        [key: string]: SideInput;
    };
    /**
     * (Optional) A mapping of local state names to state specifications.
     * If this is set, the stateful processing requirement should also
     * be placed in the pipeline requirements.
     *
     * @generated from protobuf field: map<string, org.apache.beam.model.pipeline.v1.StateSpec> state_specs = 4;
     */
    stateSpecs: {
        [key: string]: StateSpec;
    };
    /**
     * (Optional) A mapping of local timer family names to timer family
     * specifications. If this is set, the stateful processing requirement should
     * also be placed in the pipeline requirements.
     *
     * @generated from protobuf field: map<string, org.apache.beam.model.pipeline.v1.TimerFamilySpec> timer_family_specs = 9;
     */
    timerFamilySpecs: {
        [key: string]: TimerFamilySpec;
    };
    /**
     * (Optional) Only set when this ParDo contains a splittable DoFn.
     * If this is set, the corresponding standard requirement should also
     * be placed in the pipeline requirements.
     *
     * @generated from protobuf field: string restriction_coder_id = 7;
     */
    restrictionCoderId: string;
    /**
     * (Optional) Only set when this ParDo can request bundle finalization.
     * If this is set, the corresponding standard requirement should also
     * be placed in the pipeline requirements.
     *
     * @generated from protobuf field: bool requests_finalization = 8;
     */
    requestsFinalization: boolean;
    /**
     * Whether this stage requires time sorted input.
     * If this is set, the corresponding standard requirement should also
     * be placed in the pipeline requirements.
     *
     * @generated from protobuf field: bool requires_time_sorted_input = 10;
     */
    requiresTimeSortedInput: boolean;
    /**
     * Whether this stage requires stable input.
     * If this is set, the corresponding standard requirement should also
     * be placed in the pipeline requirements.
     *
     * @generated from protobuf field: bool requires_stable_input = 11;
     */
    requiresStableInput: boolean;
    /**
     * If populated, the name of the timer family spec which should be notified
     * on each window expiry.
     * If this is set, the corresponding standard requirement should also
     * be placed in the pipeline requirements.
     *
     * @generated from protobuf field: string on_window_expiration_timer_family_spec = 12;
     */
    onWindowExpirationTimerFamilySpec: string;
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.StateSpec
 */
export interface StateSpec {
    /**
     * @generated from protobuf oneof: spec
     */
    spec: {
        oneofKind: "readModifyWriteSpec";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.ReadModifyWriteStateSpec read_modify_write_spec = 1;
         */
        readModifyWriteSpec: ReadModifyWriteStateSpec;
    } | {
        oneofKind: "bagSpec";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.BagStateSpec bag_spec = 2;
         */
        bagSpec: BagStateSpec;
    } | {
        oneofKind: "combiningSpec";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.CombiningStateSpec combining_spec = 3;
         */
        combiningSpec: CombiningStateSpec;
    } | {
        oneofKind: "mapSpec";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.MapStateSpec map_spec = 4;
         */
        mapSpec: MapStateSpec;
    } | {
        oneofKind: "setSpec";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.SetStateSpec set_spec = 5;
         */
        setSpec: SetStateSpec;
    } | {
        oneofKind: "orderedListSpec";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.OrderedListStateSpec ordered_list_spec = 6;
         */
        orderedListSpec: OrderedListStateSpec;
    } | {
        oneofKind: undefined;
    };
    /**
     * (Required) URN of the protocol required by this state specification to present
     * the desired SDK-specific interface to a UDF.
     *
     * This protocol defines the SDK harness <-> Runner Harness RPC
     * interface for accessing and mutating user state.
     *
     * See StandardUserStateTypes for an enumeration of all user state types
     * defined.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.FunctionSpec protocol = 7;
     */
    protocol?: FunctionSpec;
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.ReadModifyWriteStateSpec
 */
export interface ReadModifyWriteStateSpec {
    /**
     * @generated from protobuf field: string coder_id = 1;
     */
    coderId: string;
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.BagStateSpec
 */
export interface BagStateSpec {
    /**
     * @generated from protobuf field: string element_coder_id = 1;
     */
    elementCoderId: string;
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.OrderedListStateSpec
 */
export interface OrderedListStateSpec {
    /**
     * @generated from protobuf field: string element_coder_id = 1;
     */
    elementCoderId: string;
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.CombiningStateSpec
 */
export interface CombiningStateSpec {
    /**
     * @generated from protobuf field: string accumulator_coder_id = 1;
     */
    accumulatorCoderId: string;
    /**
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.FunctionSpec combine_fn = 2;
     */
    combineFn?: FunctionSpec;
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.MapStateSpec
 */
export interface MapStateSpec {
    /**
     * @generated from protobuf field: string key_coder_id = 1;
     */
    keyCoderId: string;
    /**
     * @generated from protobuf field: string value_coder_id = 2;
     */
    valueCoderId: string;
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.SetStateSpec
 */
export interface SetStateSpec {
    /**
     * @generated from protobuf field: string element_coder_id = 1;
     */
    elementCoderId: string;
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.TimerFamilySpec
 */
export interface TimerFamilySpec {
    /**
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.TimeDomain.Enum time_domain = 1;
     */
    timeDomain: TimeDomain_Enum;
    /**
     * @generated from protobuf field: string timer_family_coder_id = 2;
     */
    timerFamilyCoderId: string;
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.IsBounded
 */
export interface IsBounded {
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.IsBounded.Enum
 */
export declare enum IsBounded_Enum {
    /**
     * @generated from protobuf enum value: UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * @generated from protobuf enum value: UNBOUNDED = 1;
     */
    UNBOUNDED = 1,
    /**
     * @generated from protobuf enum value: BOUNDED = 2;
     */
    BOUNDED = 2
}
/**
 * The payload for the primitive Read transform.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.ReadPayload
 */
export interface ReadPayload {
    /**
     * (Required) The FunctionSpec of the source for this Read.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.FunctionSpec source = 1;
     */
    source?: FunctionSpec;
    /**
     * (Required) Whether the source is bounded or unbounded
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.IsBounded.Enum is_bounded = 2;
     */
    isBounded: IsBounded_Enum;
}
/**
 * The payload for the WindowInto transform.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.WindowIntoPayload
 */
export interface WindowIntoPayload {
    /**
     * (Required) The FunctionSpec of the WindowFn.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.FunctionSpec window_fn = 1;
     */
    windowFn?: FunctionSpec;
}
/**
 * The payload for the special-but-not-primitive Combine transform.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.CombinePayload
 */
export interface CombinePayload {
    /**
     * (Required) The FunctionSpec of the CombineFn.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.FunctionSpec combine_fn = 1;
     */
    combineFn?: FunctionSpec;
    /**
     * (Required) A reference to the Coder to use for accumulators of the CombineFn
     *
     * @generated from protobuf field: string accumulator_coder_id = 2;
     */
    accumulatorCoderId: string;
}
/**
 * The payload for the test-only primitive TestStream
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.TestStreamPayload
 */
export interface TestStreamPayload {
    /**
     * (Required) the coder for elements in the TestStream events
     *
     * @generated from protobuf field: string coder_id = 1;
     */
    coderId: string;
    /**
     * (Optional) If specified, the TestStream will replay these events.
     *
     * @generated from protobuf field: repeated org.apache.beam.model.pipeline.v1.TestStreamPayload.Event events = 2;
     */
    events: TestStreamPayload_Event[];
    /**
     * (Optional) If specified, points to a TestStreamService to be
     * used to retrieve events.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.ApiServiceDescriptor endpoint = 3;
     */
    endpoint?: ApiServiceDescriptor;
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.TestStreamPayload.Event
 */
export interface TestStreamPayload_Event {
    /**
     * @generated from protobuf oneof: event
     */
    event: {
        oneofKind: "watermarkEvent";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.TestStreamPayload.Event.AdvanceWatermark watermark_event = 1;
         */
        watermarkEvent: TestStreamPayload_Event_AdvanceWatermark;
    } | {
        oneofKind: "processingTimeEvent";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.TestStreamPayload.Event.AdvanceProcessingTime processing_time_event = 2;
         */
        processingTimeEvent: TestStreamPayload_Event_AdvanceProcessingTime;
    } | {
        oneofKind: "elementEvent";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.TestStreamPayload.Event.AddElements element_event = 3;
         */
        elementEvent: TestStreamPayload_Event_AddElements;
    } | {
        oneofKind: undefined;
    };
}
/**
 * Advances the watermark to the specified timestamp.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.TestStreamPayload.Event.AdvanceWatermark
 */
export interface TestStreamPayload_Event_AdvanceWatermark {
    /**
     * (Required) The watermark in millisecond to advance to.
     *
     * @generated from protobuf field: int64 new_watermark = 1;
     */
    newWatermark: bigint;
    /**
     * (Optional) The output watermark tag for a PCollection. If unspecified
     * or with an empty string, this will default to the Main PCollection
     * Output
     *
     * @generated from protobuf field: string tag = 2;
     */
    tag: string;
}
/**
 * Advances the processing time clock by the specified amount.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.TestStreamPayload.Event.AdvanceProcessingTime
 */
export interface TestStreamPayload_Event_AdvanceProcessingTime {
    /**
     * (Required) The duration in millisecond to advance by.
     *
     * @generated from protobuf field: int64 advance_duration = 1;
     */
    advanceDuration: bigint;
}
/**
 * Adds elements to the stream to be emitted.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.TestStreamPayload.Event.AddElements
 */
export interface TestStreamPayload_Event_AddElements {
    /**
     * (Required) The elements to add to the TestStream.
     *
     * @generated from protobuf field: repeated org.apache.beam.model.pipeline.v1.TestStreamPayload.TimestampedElement elements = 1;
     */
    elements: TestStreamPayload_TimestampedElement[];
    /**
     * (Optional) The output PCollection tag to add these elements to. If
     * unspecified or with an empty string, this will default to the Main
     * PCollection Output.
     *
     * @generated from protobuf field: string tag = 3;
     */
    tag: string;
}
/**
 * A single element inside of the TestStream.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.TestStreamPayload.TimestampedElement
 */
export interface TestStreamPayload_TimestampedElement {
    /**
     * (Required) The element encoded. Currently the TestStream only supports
     * encoding primitives.
     *
     * @generated from protobuf field: bytes encoded_element = 1;
     */
    encodedElement: Uint8Array;
    /**
     * (Required) The event timestamp in millisecond of this element.
     *
     * @generated from protobuf field: int64 timestamp = 2;
     */
    timestamp: bigint;
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.EventsRequest
 */
export interface EventsRequest {
    /**
     * The set of PCollections to read from. These are the PTransform outputs
     * local names. These are a subset of the TestStream's outputs. This allows
     * Interactive Beam to cache many PCollections from a pipeline then replay a
     * subset of them.
     *
     * @generated from protobuf field: repeated string output_ids = 1;
     */
    outputIds: string[];
}
/**
 * The payload for the special-but-not-primitive WriteFiles transform.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.WriteFilesPayload
 */
export interface WriteFilesPayload {
    /**
     * (Required) The FunctionSpec of the FileBasedSink.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.FunctionSpec sink = 1;
     */
    sink?: FunctionSpec;
    /**
     * (Required) The format function.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.FunctionSpec format_function = 2;
     */
    formatFunction?: FunctionSpec;
    /**
     * @generated from protobuf field: bool windowed_writes = 3;
     */
    windowedWrites: boolean;
    /**
     * @generated from protobuf field: bool runner_determined_sharding = 4;
     */
    runnerDeterminedSharding: boolean;
    /**
     * @generated from protobuf field: map<string, org.apache.beam.model.pipeline.v1.SideInput> side_inputs = 5;
     */
    sideInputs: {
        [key: string]: SideInput;
    };
}
/**
 * Payload used by Google Cloud Pub/Sub read transform.
 * This can be used by runners that wish to override Beam Pub/Sub read transform
 * with a native implementation.
 * The SDK should guarantee that only one of topic, subscription,
 * topic_runtime_overridden and subscription_runtime_overridden is set.
 * The output of PubSubReadPayload should be bytes of serialized PubsubMessage
 * proto if with_attributes == true. Otherwise, the bytes is the raw payload.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.PubSubReadPayload
 */
export interface PubSubReadPayload {
    /**
     * Topic to read from. Exactly one of topic or subscription should be set.
     * Topic format is: /topics/project_id/subscription_name
     *
     * @generated from protobuf field: string topic = 1;
     */
    topic: string;
    /**
     * Subscription to read from. Exactly one of topic or subscription should be set.
     * Subscription format is: /subscriptions/project_id/subscription_name
     *
     * @generated from protobuf field: string subscription = 2;
     */
    subscription: string;
    /**
     * Attribute that provides element timestamps.
     *
     * @generated from protobuf field: string timestamp_attribute = 3;
     */
    timestampAttribute: string;
    /**
     * Attribute to be used for uniquely identifying messages.
     *
     * @generated from protobuf field: string id_attribute = 4;
     */
    idAttribute: string;
    /**
     * If true, reads Pub/Sub payload as well as attributes. If false, reads only the payload.
     *
     * @generated from protobuf field: bool with_attributes = 5;
     */
    withAttributes: boolean;
    /**
     * If set, the topic is expected to be provided during runtime.
     *
     * @generated from protobuf field: string topic_runtime_overridden = 6;
     */
    topicRuntimeOverridden: string;
    /**
     * If set, the subscription that is expected to be provided during runtime.
     *
     * @generated from protobuf field: string subscription_runtime_overridden = 7;
     */
    subscriptionRuntimeOverridden: string;
}
/**
 * Payload used by Google Cloud Pub/Sub write transform.
 * This can be used by runners that wish to override Beam Pub/Sub write transform
 * with a native implementation.
 * The SDK should guarantee that only one of topic and topic_runtime_overridden
 * is set.
 * The output of PubSubWritePayload should be bytes if serialized PubsubMessage
 * proto.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.PubSubWritePayload
 */
export interface PubSubWritePayload {
    /**
     * Topic to write to.
     * Topic format is: /topics/project_id/subscription_name
     *
     * @generated from protobuf field: string topic = 1;
     */
    topic: string;
    /**
     * Attribute that provides element timestamps.
     *
     * @generated from protobuf field: string timestamp_attribute = 2;
     */
    timestampAttribute: string;
    /**
     * Attribute that uniquely identify messages.
     *
     * @generated from protobuf field: string id_attribute = 3;
     */
    idAttribute: string;
    /**
     * If set, the topic is expected to be provided during runtime.
     *
     * @generated from protobuf field: string topic_runtime_overridden = 4;
     */
    topicRuntimeOverridden: string;
}
/**
 * Payload for GroupIntoBatches composite transform.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.GroupIntoBatchesPayload
 */
export interface GroupIntoBatchesPayload {
    /**
     * Max size of a batch.
     *
     * @generated from protobuf field: int64 batch_size = 1;
     */
    batchSize: bigint;
    /**
     * Max byte size of a batch in element.
     *
     * @generated from protobuf field: int64 batch_size_bytes = 3;
     */
    batchSizeBytes: bigint;
    /**
     * (Optional) Max duration a batch is allowed to be cached in states.
     *
     * @generated from protobuf field: int64 max_buffering_duration_millis = 2;
     */
    maxBufferingDurationMillis: bigint;
}
/**
 * A coder, the binary format for serialization and deserialization of data in
 * a pipeline.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.Coder
 */
export interface Coder {
    /**
     * (Required) A specification for the coder, as a URN plus parameters. This
     * may be a cross-language agreed-upon format, or it may be a "custom coder"
     * that can only be used by a particular SDK. It does not include component
     * coders, as it is beneficial for these to be comprehensible to a runner
     * regardless of whether the binary format is agreed-upon.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.FunctionSpec spec = 1;
     */
    spec?: FunctionSpec;
    /**
     * (Optional) If this coder is parametric, such as ListCoder(VarIntCoder),
     * this is a list of the components. In order for encodings to be identical,
     * the FunctionSpec and all components must be identical, recursively.
     *
     * @generated from protobuf field: repeated string component_coder_ids = 2;
     */
    componentCoderIds: string[];
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.StandardCoders
 */
export interface StandardCoders {
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.StandardCoders.Enum
 */
export declare enum StandardCoders_Enum {
    /**
     * Components: None
     *
     * @generated from protobuf enum value: BYTES = 0;
     */
    BYTES = 0,
    /**
     * Components: None
     *
     * @generated from protobuf enum value: STRING_UTF8 = 10;
     */
    STRING_UTF8 = 10,
    /**
     * Components: The key and value coder, in that order.
     *
     * @generated from protobuf enum value: KV = 1;
     */
    KV = 1,
    /**
     * Components: None
     *
     * @generated from protobuf enum value: BOOL = 12;
     */
    BOOL = 12,
    /**
     * Variable length Encodes a 64-bit integer.
     * Components: None
     *
     * @generated from protobuf enum value: VARINT = 2;
     */
    VARINT = 2,
    /**
     * Encodes the floating point value as a big-endian 64-bit integer
     * according to the IEEE 754 double format bit layout.
     * Components: None
     *
     * @generated from protobuf enum value: DOUBLE = 11;
     */
    DOUBLE = 11,
    /**
     * Encodes an iterable of elements.
     *
     * The encoding for an iterable [e1...eN] of known length N is
     *
     *    fixed32(N)
     *    encode(e1) encode(e2) encode(e3) ... encode(eN)
     *
     * If the length is unknown, it is batched up into groups of size b1..bM
     * and encoded as
     *
     *     fixed32(-1)
     *     varInt64(b1) encode(e1) encode(e2) ... encode(e_b1)
     *     varInt64(b2) encode(e_(b1+1)) encode(e_(b1+2)) ... encode(e_(b1+b2))
     *     ...
     *     varInt64(bM) encode(e_(N-bM+1)) encode(e_(N-bM+2)) ... encode(eN)
     *     varInt64(0)
     *
     * Components: Coder for a single element.
     *
     * @generated from protobuf enum value: ITERABLE = 3;
     */
    ITERABLE = 3,
    /**
     * Encodes a timer containing a user key, a dynamic timer tag, a clear bit,
     * a fire timestamp, a hold timestamp, the windows and the paneinfo.
     * The encoding is represented as:
     *   user key - user defined key, uses the component coder.
     *   dynamic timer tag - a string which identifies a timer.
     *   windows - uses component coders.
     *   clear bit - a boolean set for clearing the timer.
     *   fire timestamp - a big endian 8 byte integer representing millis-since-epoch.
     *     The encoded representation is shifted so that the byte representation of
     *     negative values are lexicographically ordered before the byte representation
     *     of positive values. This is typically done by subtracting -9223372036854775808
     *     from the value and encoding it as a signed big endian integer. Example values:
     *
     *     -9223372036854775808: 00 00 00 00 00 00 00 00
     *                     -255: 7F FF FF FF FF FF FF 01
     *                       -1: 7F FF FF FF FF FF FF FF
     *                        0: 80 00 00 00 00 00 00 00
     *                        1: 80 00 00 00 00 00 00 01
     *                      256: 80 00 00 00 00 00 01 00
     *      9223372036854775807: FF FF FF FF FF FF FF FF
     *   hold timestamp - similar to the fire timestamp.
     *   paneinfo - similar to the paneinfo of the windowed_value.
     * Components: Coder for the key and windows.
     *
     * @generated from protobuf enum value: TIMER = 4;
     */
    TIMER = 4,
    /**
     * Components: None
     *
     * @generated from protobuf enum value: INTERVAL_WINDOW = 5;
     */
    INTERVAL_WINDOW = 5,
    /**
     * Components: The coder to attach a length prefix to
     *
     * @generated from protobuf enum value: LENGTH_PREFIX = 6;
     */
    LENGTH_PREFIX = 6,
    /**
     * Components: None
     *
     * @generated from protobuf enum value: GLOBAL_WINDOW = 7;
     */
    GLOBAL_WINDOW = 7,
    /**
     * Encodes an element, the windows it is in, the timestamp of the element,
     * and the pane of the element. The encoding is represented as:
     * timestamp windows pane element
     *   timestamp - A big endian 8 byte integer representing millis-since-epoch.
     *     The encoded representation is shifted so that the byte representation
     *     of negative values are lexicographically ordered before the byte
     *     representation of positive values. This is typically done by
     *     subtracting -9223372036854775808 from the value and encoding it as a
     *     signed big endian integer. Example values:
     *
     *     -9223372036854775808: 00 00 00 00 00 00 00 00
     *                     -255: 7F FF FF FF FF FF FF 01
     *                       -1: 7F FF FF FF FF FF FF FF
     *                        0: 80 00 00 00 00 00 00 00
     *                        1: 80 00 00 00 00 00 00 01
     *                      256: 80 00 00 00 00 00 01 00
     *      9223372036854775807: FF FF FF FF FF FF FF FF
     *
     *   windows - The windows are encoded using the beam:coder:iterable:v1
     *     format, where the windows are encoded using the supplied window
     *     coder.
     *
     *   pane - The first byte of the pane info determines which type of
     *     encoding is used, as well as the is_first, is_last, and timing
     *     fields. If this byte is bits [0 1 2 3 4 5 6 7], then:
     *     * bits [0 1 2 3] determine the encoding as follows:
     *         0000 - The entire pane info is encoded as a single byte.
     *                The is_first, is_last, and timing fields are encoded
     *                as below, and the index and non-speculative index are
     *                both zero (and hence are not encoded here).
     *         0001 - The pane info is encoded as this byte plus a single
     *                VarInt encoed integer representing the pane index. The
     *                non-speculative index can be derived as follows:
     *                  -1 if the pane is early, otherwise equal to index.
     *         0010 - The pane info is encoded as this byte plus two VarInt
     *                encoded integers representing the pane index and
     *                non-speculative index respectively.
     *     * bits [4 5] encode the timing as follows:
     *         00 - early
     *         01 - on time
     *         10 - late
     *         11 - unknown
     *     * bit 6 is 1 if this is the first pane, 0 otherwise.
     *     * bit 7 is 1 if this is the last pane, 0 otherwise.
     *
     *   element - The element incoded using the supplied element coder.
     *
     * Components: The element coder and the window coder, in that order.
     *
     * @generated from protobuf enum value: WINDOWED_VALUE = 8;
     */
    WINDOWED_VALUE = 8,
    /**
     * A windowed value coder with parameterized timestamp, windows and pane info.
     * Encodes an element with only the value of the windowed value.
     * Decodes the value and assigns the parameterized timestamp, windows and pane info to the
     * windowed value.
     * Components: The element coder and the window coder, in that order
     * The payload of this coder is an encoded windowed value using the
     * beam:coder:windowed_value:v1 coder parameterized by a beam:coder:bytes:v1
     * element coder and the window coder that this param_windowed_value coder uses.
     *
     * @generated from protobuf enum value: PARAM_WINDOWED_VALUE = 14;
     */
    PARAM_WINDOWED_VALUE = 14,
    /**
     * Encodes an iterable of elements, some of which may be stored elsewhere.
     *
     * The encoding for a state-backed iterable is the same as that for
     * an iterable, but the final varInt64(0) terminating the set of batches
     * may instead be replaced by
     *
     *     varInt64(-1)
     *     varInt64(len(token))
     *     token
     *
     * where token is an opaque byte string that can be used to fetch the
     * remainder of the iterable (e.g. over the state API).
     *
     * Components: Coder for a single element.
     * Experimental.
     *
     * @generated from protobuf enum value: STATE_BACKED_ITERABLE = 9;
     */
    STATE_BACKED_ITERABLE = 9,
    /**
     * Encodes an arbitrary user defined window and its max timestamp (inclusive).
     * The encoding format is:
     *   maxTimestamp window
     *
     *   maxTimestamp - A big endian 8 byte integer representing millis-since-epoch.
     *     The encoded representation is shifted so that the byte representation
     *     of negative values are lexicographically ordered before the byte
     *     representation of positive values. This is typically done by
     *     subtracting -9223372036854775808 from the value and encoding it as a
     *     signed big endian integer. Example values:
     *
     *     -9223372036854775808: 00 00 00 00 00 00 00 00
     *                     -255: 7F FF FF FF FF FF FF 01
     *                       -1: 7F FF FF FF FF FF FF FF
     *                        0: 80 00 00 00 00 00 00 00
     *                        1: 80 00 00 00 00 00 00 01
     *                      256: 80 00 00 00 00 00 01 00
     *      9223372036854775807: FF FF FF FF FF FF FF FF
     *
     *   window - the window is encoded using the supplied window coder.
     *
     * Components: Coder for the custom window type.
     *
     * @generated from protobuf enum value: CUSTOM_WINDOW = 16;
     */
    CUSTOM_WINDOW = 16,
    /**
     * Encodes a "row", an element with a known schema, defined by an
     * instance of Schema from schema.proto.
     *
     * A row is encoded as the concatenation of:
     *   - The number of attributes in the schema, encoded with
     *     beam:coder:varint:v1. This makes it possible to detect certain
     *     allowed schema changes (appending or removing columns) in
     *     long-running streaming pipelines.
     *   - A byte array representing a packed bitset indicating null fields (a
     *     1 indicating a null) encoded with beam:coder:bytes:v1. The unused
     *     bits in the last byte must be set to 0. If there are no nulls an
     *     empty byte array is encoded.
     *     The two-byte bitset (not including the lenghth-prefix) for the row
     *     [NULL, 0, 0, 0, NULL, 0, 0, NULL, 0, NULL] would be
     *     [0b10010001, 0b00000010]
     *   - An encoding for each non-null field, concatenated together.
     *
     * Schema types are mapped to coders as follows:
     *   AtomicType:
     *     BYTE:      not yet a standard coder (https://github.com/apache/beam/issues/19815)
     *     INT16:     not yet a standard coder (https://github.com/apache/beam/issues/19815)
     *     INT32:     beam:coder:varint:v1
     *     INT64:     beam:coder:varint:v1
     *     FLOAT:     not yet a standard coder (https://github.com/apache/beam/issues/19815)
     *     DOUBLE:    beam:coder:double:v1
     *     STRING:    beam:coder:string_utf8:v1
     *     BOOLEAN:   beam:coder:bool:v1
     *     BYTES:     beam:coder:bytes:v1
     *   ArrayType:   beam:coder:iterable:v1 (always has a known length)
     *   MapType:     not a standard coder, specification defined below.
     *   RowType:     beam:coder:row:v1
     *   LogicalType: Uses the coder for its representation.
     *
     * The MapType is encoded by:
     *   - An INT32 representing the size of the map (N)
     *   - Followed by N interleaved keys and values, encoded with their
     *     corresponding coder.
     *
     * Nullable types in container types (ArrayType, MapType) per the
     * encoding described for general Nullable types below.
     *
     * Logical types understood by all SDKs should be defined in schema.proto.
     * Example of well known logical types:
     *   beam:logical_type:schema:v1
     *   - Representation type: BYTES
     *   - A Beam Schema stored as a serialized proto.
     *
     * The payload for RowCoder is an instance of Schema.
     * Components: None
     * Experimental.
     *
     * @generated from protobuf enum value: ROW = 13;
     */
    ROW = 13,
    /**
     * Encodes a user key and a shard id which is an opaque byte string.
     *
     * The encoding for a sharded key consists of a shard id byte string and the
     * encoded user key in the following order:
     *
     *     - shard id using beam:coder:bytes:v1
     *     - encoded user key
     *
     * Examples:
     * user key with an empty shard id
     *     0x00
     *     encode(user_key)
     *
     * user key with a shard id taking up two bytes.
     *     0x02
     *     0x11 0x22
     *     encode(user_key)
     *
     * Components: the user key coder.
     * Experimental.
     *
     * @generated from protobuf enum value: SHARDED_KEY = 15;
     */
    SHARDED_KEY = 15,
    /**
     * Wraps a coder of a potentially null value
     * A Nullable Type is encoded by:
     *   - A one byte null indicator, 0x00 for null values, or 0x01 for present
     *     values.
     *   - For present values the null indicator is followed by the value
     *     encoded with it's corresponding coder.
     * Components: single coder for the value
     *
     * @generated from protobuf enum value: NULLABLE = 17;
     */
    NULLABLE = 17
}
/**
 * A windowing strategy describes the window function, triggering, allowed
 * lateness, and accumulation mode for a PCollection.
 *
 * TODO: consider inlining field on PCollection
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.WindowingStrategy
 */
export interface WindowingStrategy {
    /**
     * (Required) The FunctionSpec of the UDF that assigns windows,
     * merges windows, and shifts timestamps before they are
     * combined according to the OutputTime.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.FunctionSpec window_fn = 1;
     */
    windowFn?: FunctionSpec;
    /**
     * (Required) Whether or not the window fn is merging.
     *
     * This knowledge is required for many optimizations.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.MergeStatus.Enum merge_status = 2;
     */
    mergeStatus: MergeStatus_Enum;
    /**
     * (Required) The coder for the windows of this PCollection.
     *
     * @generated from protobuf field: string window_coder_id = 3;
     */
    windowCoderId: string;
    /**
     * (Required) The trigger to use when grouping this PCollection.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Trigger trigger = 4;
     */
    trigger?: Trigger;
    /**
     * (Required) The accumulation mode indicates whether new panes are a full
     * replacement for prior panes or whether they are deltas to be combined
     * with other panes (the combine should correspond to whatever the upstream
     * grouping transform is).
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.AccumulationMode.Enum accumulation_mode = 5;
     */
    accumulationMode: AccumulationMode_Enum;
    /**
     * (Required) The OutputTime specifies, for a grouping transform, how to
     * compute the aggregate timestamp. The window_fn will first possibly shift
     * it later, then the OutputTime takes the max, min, or ignores it and takes
     * the end of window.
     *
     * This is actually only for input to grouping transforms, but since they
     * may be introduced in runner-specific ways, it is carried along with the
     * windowing strategy.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.OutputTime.Enum output_time = 6;
     */
    outputTime: OutputTime_Enum;
    /**
     * (Required) Indicate when output should be omitted upon window expiration.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.ClosingBehavior.Enum closing_behavior = 7;
     */
    closingBehavior: ClosingBehavior_Enum;
    /**
     * (Required) The duration, in milliseconds, beyond the end of a window at
     * which the window becomes droppable.
     *
     * @generated from protobuf field: int64 allowed_lateness = 8;
     */
    allowedLateness: bigint;
    /**
     * (Required) Indicate whether empty on-time panes should be omitted.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.OnTimeBehavior.Enum on_time_behavior = 9;
     */
    onTimeBehavior: OnTimeBehavior_Enum;
    /**
     * (Required) Whether or not the window fn assigns inputs to exactly one window
     *
     * This knowledge is required for some optimizations
     *
     * @generated from protobuf field: bool assigns_to_one_window = 10;
     */
    assignsToOneWindow: boolean;
    /**
     * (Optional) Environment where the current window_fn should be applied in.
     * Runner that executes the pipeline may choose to override this if needed.
     * If not specified, environment will be decided by the runner.
     *
     * @generated from protobuf field: string environment_id = 11;
     */
    environmentId: string;
}
/**
 * Whether or not a PCollection's WindowFn is non-merging, merging, or
 * merging-but-already-merged, in which case a subsequent GroupByKey is almost
 * always going to do something the user does not want
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.MergeStatus
 */
export interface MergeStatus {
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.MergeStatus.Enum
 */
export declare enum MergeStatus_Enum {
    /**
     * @generated from protobuf enum value: UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * The WindowFn does not require merging.
     * Examples: global window, FixedWindows, SlidingWindows
     *
     * @generated from protobuf enum value: NON_MERGING = 1;
     */
    NON_MERGING = 1,
    /**
     * The WindowFn is merging and the PCollection has not had merging
     * performed.
     * Example: Sessions prior to a GroupByKey
     *
     * @generated from protobuf enum value: NEEDS_MERGE = 2;
     */
    NEEDS_MERGE = 2,
    /**
     * The WindowFn is merging and the PCollection has had merging occur
     * already.
     * Example: Sessions after a GroupByKey
     *
     * @generated from protobuf enum value: ALREADY_MERGED = 3;
     */
    ALREADY_MERGED = 3
}
/**
 * Whether or not subsequent outputs of aggregations should be entire
 * replacement values or just the aggregation of inputs received since
 * the prior output.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.AccumulationMode
 */
export interface AccumulationMode {
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.AccumulationMode.Enum
 */
export declare enum AccumulationMode_Enum {
    /**
     * @generated from protobuf enum value: UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * The aggregation is discarded when it is output
     *
     * @generated from protobuf enum value: DISCARDING = 1;
     */
    DISCARDING = 1,
    /**
     * The aggregation is accumulated across outputs
     *
     * @generated from protobuf enum value: ACCUMULATING = 2;
     */
    ACCUMULATING = 2,
    /**
     * The aggregation emits retractions when it is output
     *
     * @generated from protobuf enum value: RETRACTING = 3;
     */
    RETRACTING = 3
}
/**
 * Controls whether or not an aggregating transform should output data
 * when a window expires.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.ClosingBehavior
 */
export interface ClosingBehavior {
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.ClosingBehavior.Enum
 */
export declare enum ClosingBehavior_Enum {
    /**
     * @generated from protobuf enum value: UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * Emit output when a window expires, whether or not there has been
     * any new data since the last output.
     *
     * @generated from protobuf enum value: EMIT_ALWAYS = 1;
     */
    EMIT_ALWAYS = 1,
    /**
     * Only emit output when new data has arrives since the last output
     *
     * @generated from protobuf enum value: EMIT_IF_NONEMPTY = 2;
     */
    EMIT_IF_NONEMPTY = 2
}
/**
 * Controls whether or not an aggregating transform should output data
 * when an on-time pane is empty.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.OnTimeBehavior
 */
export interface OnTimeBehavior {
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.OnTimeBehavior.Enum
 */
export declare enum OnTimeBehavior_Enum {
    /**
     * @generated from protobuf enum value: UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * Always fire the on-time pane. Even if there is no new data since
     * the previous firing, an element will be produced.
     *
     * @generated from protobuf enum value: FIRE_ALWAYS = 1;
     */
    FIRE_ALWAYS = 1,
    /**
     * Only fire the on-time pane if there is new data since the previous firing.
     *
     * @generated from protobuf enum value: FIRE_IF_NONEMPTY = 2;
     */
    FIRE_IF_NONEMPTY = 2
}
/**
 * When a number of windowed, timestamped inputs are aggregated, the timestamp
 * for the resulting output.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.OutputTime
 */
export interface OutputTime {
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.OutputTime.Enum
 */
export declare enum OutputTime_Enum {
    /**
     * @generated from protobuf enum value: UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * The output has the timestamp of the end of the window.
     *
     * @generated from protobuf enum value: END_OF_WINDOW = 1;
     */
    END_OF_WINDOW = 1,
    /**
     * The output has the latest timestamp of the input elements since
     * the last output.
     *
     * @generated from protobuf enum value: LATEST_IN_PANE = 2;
     */
    LATEST_IN_PANE = 2,
    /**
     * The output has the earliest timestamp of the input elements since
     * the last output.
     *
     * @generated from protobuf enum value: EARLIEST_IN_PANE = 3;
     */
    EARLIEST_IN_PANE = 3
}
/**
 * The different time domains in the Beam model.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.TimeDomain
 */
export interface TimeDomain {
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.TimeDomain.Enum
 */
export declare enum TimeDomain_Enum {
    /**
     * @generated from protobuf enum value: UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * Event time is time from the perspective of the data
     *
     * @generated from protobuf enum value: EVENT_TIME = 1;
     */
    EVENT_TIME = 1,
    /**
     * Processing time is time from the perspective of the
     * execution of your pipeline
     *
     * @generated from protobuf enum value: PROCESSING_TIME = 2;
     */
    PROCESSING_TIME = 2
}
/**
 * A small DSL for expressing when to emit new aggregations
 * from a GroupByKey or CombinePerKey
 *
 * A trigger is described in terms of when it is _ready_ to permit output.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.Trigger
 */
export interface Trigger {
    /**
     * @generated from protobuf oneof: trigger
     */
    trigger: {
        oneofKind: "afterAll";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Trigger.AfterAll after_all = 1;
         */
        afterAll: Trigger_AfterAll;
    } | {
        oneofKind: "afterAny";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Trigger.AfterAny after_any = 2;
         */
        afterAny: Trigger_AfterAny;
    } | {
        oneofKind: "afterEach";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Trigger.AfterEach after_each = 3;
         */
        afterEach: Trigger_AfterEach;
    } | {
        oneofKind: "afterEndOfWindow";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Trigger.AfterEndOfWindow after_end_of_window = 4;
         */
        afterEndOfWindow: Trigger_AfterEndOfWindow;
    } | {
        oneofKind: "afterProcessingTime";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Trigger.AfterProcessingTime after_processing_time = 5;
         */
        afterProcessingTime: Trigger_AfterProcessingTime;
    } | {
        oneofKind: "afterSynchronizedProcessingTime";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Trigger.AfterSynchronizedProcessingTime after_synchronized_processing_time = 6;
         */
        afterSynchronizedProcessingTime: Trigger_AfterSynchronizedProcessingTime;
    } | {
        oneofKind: "always";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Trigger.Always always = 12;
         */
        always: Trigger_Always;
    } | {
        oneofKind: "default";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Trigger.Default default = 7;
         */
        default: Trigger_Default;
    } | {
        oneofKind: "elementCount";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Trigger.ElementCount element_count = 8;
         */
        elementCount: Trigger_ElementCount;
    } | {
        oneofKind: "never";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Trigger.Never never = 9;
         */
        never: Trigger_Never;
    } | {
        oneofKind: "orFinally";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Trigger.OrFinally or_finally = 10;
         */
        orFinally: Trigger_OrFinally;
    } | {
        oneofKind: "repeat";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Trigger.Repeat repeat = 11;
         */
        repeat: Trigger_Repeat;
    } | {
        oneofKind: undefined;
    };
}
/**
 * Ready when all subtriggers are ready.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.Trigger.AfterAll
 */
export interface Trigger_AfterAll {
    /**
     * @generated from protobuf field: repeated org.apache.beam.model.pipeline.v1.Trigger subtriggers = 1;
     */
    subtriggers: Trigger[];
}
/**
 * Ready when any subtrigger is ready.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.Trigger.AfterAny
 */
export interface Trigger_AfterAny {
    /**
     * @generated from protobuf field: repeated org.apache.beam.model.pipeline.v1.Trigger subtriggers = 1;
     */
    subtriggers: Trigger[];
}
/**
 * Starting with the first subtrigger, ready when the _current_ subtrigger
 * is ready. After output, advances the current trigger by one.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.Trigger.AfterEach
 */
export interface Trigger_AfterEach {
    /**
     * @generated from protobuf field: repeated org.apache.beam.model.pipeline.v1.Trigger subtriggers = 1;
     */
    subtriggers: Trigger[];
}
/**
 * Ready after the input watermark is past the end of the window.
 *
 * May have implicitly-repeated subtriggers for early and late firings.
 * When the end of the window is reached, the trigger transitions between
 * the subtriggers.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.Trigger.AfterEndOfWindow
 */
export interface Trigger_AfterEndOfWindow {
    /**
     * (Optional) A trigger governing output prior to the end of the window.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Trigger early_firings = 1;
     */
    earlyFirings?: Trigger;
    /**
     * (Optional) A trigger governing output after the end of the window.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Trigger late_firings = 2;
     */
    lateFirings?: Trigger;
}
/**
 * After input arrives, ready when the specified delay has passed.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.Trigger.AfterProcessingTime
 */
export interface Trigger_AfterProcessingTime {
    /**
     * (Required) The transforms to apply to an arriving element's timestamp,
     * in order
     *
     * @generated from protobuf field: repeated org.apache.beam.model.pipeline.v1.TimestampTransform timestamp_transforms = 1;
     */
    timestampTransforms: TimestampTransform[];
}
/**
 * Ready whenever upstream processing time has all caught up with
 * the arrival time of an input element
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.Trigger.AfterSynchronizedProcessingTime
 */
export interface Trigger_AfterSynchronizedProcessingTime {
}
/**
 * The default trigger. Equivalent to Repeat { AfterEndOfWindow } but
 * specially denoted to indicate the user did not alter the triggering.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.Trigger.Default
 */
export interface Trigger_Default {
}
/**
 * Ready whenever the requisite number of input elements have arrived
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.Trigger.ElementCount
 */
export interface Trigger_ElementCount {
    /**
     * @generated from protobuf field: int32 element_count = 1;
     */
    elementCount: number;
}
/**
 * Never ready. There will only be an ON_TIME output and a final
 * output at window expiration.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.Trigger.Never
 */
export interface Trigger_Never {
}
/**
 * Always ready. This can also be expressed as ElementCount(1) but
 * is more explicit.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.Trigger.Always
 */
export interface Trigger_Always {
}
/**
 * Ready whenever either of its subtriggers are ready, but finishes output
 * when the finally subtrigger fires.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.Trigger.OrFinally
 */
export interface Trigger_OrFinally {
    /**
     * (Required) Trigger governing main output; may fire repeatedly.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Trigger main = 1;
     */
    main?: Trigger;
    /**
     * (Required) Trigger governing termination of output.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Trigger finally = 2;
     */
    finally?: Trigger;
}
/**
 * Ready whenever the subtrigger is ready; resets state when the subtrigger
 * completes.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.Trigger.Repeat
 */
export interface Trigger_Repeat {
    /**
     * (Require) Trigger that is run repeatedly.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Trigger subtrigger = 1;
     */
    subtrigger?: Trigger;
}
/**
 * A specification for a transformation on a timestamp.
 *
 * Primarily used by AfterProcessingTime triggers to transform
 * the arrival time of input to a target time for firing.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.TimestampTransform
 */
export interface TimestampTransform {
    /**
     * @generated from protobuf oneof: timestamp_transform
     */
    timestampTransform: {
        oneofKind: "delay";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.TimestampTransform.Delay delay = 1;
         */
        delay: TimestampTransform_Delay;
    } | {
        oneofKind: "alignTo";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.TimestampTransform.AlignTo align_to = 2;
         */
        alignTo: TimestampTransform_AlignTo;
    } | {
        oneofKind: undefined;
    };
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.TimestampTransform.Delay
 */
export interface TimestampTransform_Delay {
    /**
     * (Required) The delay, in milliseconds.
     *
     * @generated from protobuf field: int64 delay_millis = 1;
     */
    delayMillis: bigint;
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.TimestampTransform.AlignTo
 */
export interface TimestampTransform_AlignTo {
    /**
     * (Required) A duration to which delays should be quantized
     * in milliseconds.
     *
     * @generated from protobuf field: int64 period = 3;
     */
    period: bigint;
    /**
     * (Required) An offset from 0 for the quantization specified by
     * alignment_size, in milliseconds
     *
     * @generated from protobuf field: int64 offset = 4;
     */
    offset: bigint;
}
/**
 * A specification for how to "side input" a PCollection.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.SideInput
 */
export interface SideInput {
    /**
     * (Required) URN of the access pattern required by the `view_fn` to present
     * the desired SDK-specific interface to a UDF.
     *
     * This access pattern defines the SDK harness <-> Runner Harness RPC
     * interface for accessing a side input.
     *
     * See StandardSideInputTypes for an enumeration of all side input types
     * defined.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.FunctionSpec access_pattern = 1;
     */
    accessPattern?: FunctionSpec;
    /**
     * (Required) The FunctionSpec of the UDF that adapts a particular
     * access_pattern to a user-facing view type.
     *
     * For example, View.asSingleton() may include a `view_fn` that adapts a
     * specially-designed multimap to a single value per window.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.FunctionSpec view_fn = 2;
     */
    viewFn?: FunctionSpec;
    /**
     * (Required) The FunctionSpec of the UDF that maps a main input window
     * to a side input window.
     *
     * For example, when the main input is in fixed windows of one hour, this
     * can specify that the side input should be accessed according to the day
     * in which that hour falls.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.FunctionSpec window_mapping_fn = 3;
     */
    windowMappingFn?: FunctionSpec;
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.StandardArtifacts
 */
export interface StandardArtifacts {
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.StandardArtifacts.Types
 */
export declare enum StandardArtifacts_Types {
    /**
     * A URN for locally-accessible artifact files.
     * payload: ArtifactFilePayload
     *
     * @generated from protobuf enum value: FILE = 0;
     */
    FILE = 0,
    /**
     * A URN for artifacts described by URLs.
     * payload: ArtifactUrlPayload
     *
     * @generated from protobuf enum value: URL = 1;
     */
    URL = 1,
    /**
     * A URN for artifacts embedded in ArtifactInformation proto.
     * payload: EmbeddedFilePayload.
     *
     * @generated from protobuf enum value: EMBEDDED = 2;
     */
    EMBEDDED = 2,
    /**
     * A URN for Python artifacts hosted on PYPI.
     * payload: PypiPayload
     *
     * @generated from protobuf enum value: PYPI = 3;
     */
    PYPI = 3,
    /**
     * A URN for Java artifacts hosted on a Maven repository.
     * payload: MavenPayload
     *
     * @generated from protobuf enum value: MAVEN = 4;
     */
    MAVEN = 4,
    /**
     * A URN for deferred artifacts.
     * payload: DeferredArtifactPayload
     *
     * @generated from protobuf enum value: DEFERRED = 5;
     */
    DEFERRED = 5
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.StandardArtifacts.Roles
 */
export declare enum StandardArtifacts_Roles {
    /**
     * A URN for staging-to role.
     * payload: ArtifactStagingToRolePayload
     *
     * @generated from protobuf enum value: STAGING_TO = 0;
     */
    STAGING_TO = 0,
    /**
     * A URN for pip-requirements-file role.
     * payload: None
     *
     * @generated from protobuf enum value: PIP_REQUIREMENTS_FILE = 1;
     */
    PIP_REQUIREMENTS_FILE = 1,
    /**
     * A URN for the Go worker binary role.
     * This represents the executable for a Go SDK environment.
     * A Go environment may have one such artifact with this role.
     * payload: None
     *
     * @generated from protobuf enum value: GO_WORKER_BINARY = 2;
     */
    GO_WORKER_BINARY = 2
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.ArtifactFilePayload
 */
export interface ArtifactFilePayload {
    /**
     * a string for an artifact file path e.g. "/tmp/foo.jar"
     *
     * @generated from protobuf field: string path = 1;
     */
    path: string;
    /**
     * The hex-encoded sha256 checksum of the artifact.
     *
     * @generated from protobuf field: string sha256 = 2;
     */
    sha256: string;
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.ArtifactUrlPayload
 */
export interface ArtifactUrlPayload {
    /**
     * a string for an artifact URL e.g. "https://.../foo.jar" or "gs://tmp/foo.jar"
     *
     * @generated from protobuf field: string url = 1;
     */
    url: string;
    /**
     * (Optional) The hex-encoded sha256 checksum of the artifact if available.
     *
     * @generated from protobuf field: string sha256 = 2;
     */
    sha256: string;
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.EmbeddedFilePayload
 */
export interface EmbeddedFilePayload {
    /**
     * raw data bytes for an embedded artifact
     *
     * @generated from protobuf field: bytes data = 1;
     */
    data: Uint8Array;
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.PyPIPayload
 */
export interface PyPIPayload {
    /**
     * Pypi compatible artifact id e.g. "apache-beam"
     *
     * @generated from protobuf field: string artifact_id = 1;
     */
    artifactId: string;
    /**
     * Pypi compatible version string.
     *
     * @generated from protobuf field: string version = 2;
     */
    version: string;
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.MavenPayload
 */
export interface MavenPayload {
    /**
     * A string specifying Maven artifact.
     * The standard format is "groupId:artifactId:version[:packaging[:classifier]]"
     *
     * @generated from protobuf field: string artifact = 1;
     */
    artifact: string;
    /**
     * (Optional) Repository URL. If not specified, Maven central is used by default.
     *
     * @generated from protobuf field: string repository_url = 2;
     */
    repositoryUrl: string;
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.DeferredArtifactPayload
 */
export interface DeferredArtifactPayload {
    /**
     * A unique string identifier assigned by the creator of this payload. The creator may use this key to confirm
     * whether they can parse the data.
     *
     * @generated from protobuf field: string key = 1;
     */
    key: string;
    /**
     * Data for deferred artifacts. Interpretation of bytes is delegated to the creator of this payload.
     *
     * @generated from protobuf field: bytes data = 2;
     */
    data: Uint8Array;
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.ArtifactStagingToRolePayload
 */
export interface ArtifactStagingToRolePayload {
    /**
     * A generated staged name (relative path under staging directory).
     *
     * @generated from protobuf field: string staged_name = 1;
     */
    stagedName: string;
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.ArtifactInformation
 */
export interface ArtifactInformation {
    /**
     * A URN that describes the type of artifact
     *
     * @generated from protobuf field: string type_urn = 1;
     */
    typeUrn: string;
    /**
     * @generated from protobuf field: bytes type_payload = 2;
     */
    typePayload: Uint8Array;
    /**
     * A URN that describes the role of artifact
     *
     * @generated from protobuf field: string role_urn = 3;
     */
    roleUrn: string;
    /**
     * @generated from protobuf field: bytes role_payload = 4;
     */
    rolePayload: Uint8Array;
}
/**
 * An environment for executing UDFs. By default, an SDK container URL, but
 * can also be a process forked by a command, or an externally managed process.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.Environment
 */
export interface Environment {
    /**
     * (Required) The URN of the payload
     *
     * @generated from protobuf field: string urn = 2;
     */
    urn: string;
    /**
     * (Optional) The data specifying any parameters to the URN. If
     * the URN does not require any arguments, this may be omitted.
     *
     * @generated from protobuf field: bytes payload = 3;
     */
    payload: Uint8Array;
    /**
     * (Optional) Static display data for the environment. If there is none,
     * it may be omitted.
     *
     * @generated from protobuf field: repeated org.apache.beam.model.pipeline.v1.DisplayData display_data = 4;
     */
    displayData: DisplayData[];
    /**
     * (Optional) A set of capabilities this environment supports. This is
     * typically a list of common URNs designating coders, transforms, etc. that
     * this environment understands (and a runner MAY use) despite not
     * appearing in the pipeline proto. This may also be used to indicate
     * support of optional protocols not tied to a concrete component.
     *
     * @generated from protobuf field: repeated string capabilities = 5;
     */
    capabilities: string[];
    /**
     * (Optional) artifact dependency information used for executing UDFs in this environment.
     *
     * @generated from protobuf field: repeated org.apache.beam.model.pipeline.v1.ArtifactInformation dependencies = 6;
     */
    dependencies: ArtifactInformation[];
    /**
     * (Optional) A mapping of resource URNs to requested values.  The encoding
     * of the values is specified by the URN.  Resource hints are advisory;
     * a runner is free to ignore resource hints that it does not understand.
     *
     * @generated from protobuf field: map<string, bytes> resource_hints = 7;
     */
    resourceHints: {
        [key: string]: Uint8Array;
    };
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.StandardEnvironments
 */
export interface StandardEnvironments {
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.StandardEnvironments.Environments
 */
export declare enum StandardEnvironments_Environments {
    /**
     * A managed docker container to run user code.
     *
     * @generated from protobuf enum value: DOCKER = 0;
     */
    DOCKER = 0,
    /**
     * A managed native process to run user code.
     *
     * @generated from protobuf enum value: PROCESS = 1;
     */
    PROCESS = 1,
    /**
     * An external non managed process to run user code.
     *
     * @generated from protobuf enum value: EXTERNAL = 2;
     */
    EXTERNAL = 2,
    /**
     * Used as a stub when context is missing a runner-provided default environment.
     *
     * @generated from protobuf enum value: DEFAULT = 3;
     */
    DEFAULT = 3
}
/**
 * The payload of a Docker image
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.DockerPayload
 */
export interface DockerPayload {
    /**
     * @generated from protobuf field: string container_image = 1;
     */
    containerImage: string;
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.ProcessPayload
 */
export interface ProcessPayload {
    /**
     * @generated from protobuf field: string os = 1;
     */
    os: string;
    /**
     * @generated from protobuf field: string arch = 2;
     */
    arch: string;
    /**
     * @generated from protobuf field: string command = 3;
     */
    command: string;
    /**
     * @generated from protobuf field: map<string, string> env = 4;
     */
    env: {
        [key: string]: string;
    };
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.ExternalPayload
 */
export interface ExternalPayload {
    /**
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.ApiServiceDescriptor endpoint = 1;
     */
    endpoint?: ApiServiceDescriptor;
    /**
     * @generated from protobuf field: map<string, string> params = 2;
     */
    params: {
        [key: string]: string;
    };
}
/**
 * These URNs are used to indicate capabilities of environments that cannot
 * simply be expressed as a component (such as a Coder or PTransform) that this
 * environment understands.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.StandardProtocols
 */
export interface StandardProtocols {
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.StandardProtocols.Enum
 */
export declare enum StandardProtocols_Enum {
    /**
     * Indicates suport for progress reporting via the legacy Metrics proto.
     *
     * @generated from protobuf enum value: LEGACY_PROGRESS_REPORTING = 0;
     */
    LEGACY_PROGRESS_REPORTING = 0,
    /**
     * Indicates suport for progress reporting via the new MonitoringInfo proto.
     *
     * @generated from protobuf enum value: PROGRESS_REPORTING = 1;
     */
    PROGRESS_REPORTING = 1,
    /**
     * Indicates suport for worker status protocol defined at
     * https://s.apache.org/beam-fn-api-harness-status.
     *
     * @generated from protobuf enum value: WORKER_STATUS = 2;
     */
    WORKER_STATUS = 2,
    /**
     * Indicates this SDK can take advantage of multiple cores when processing
     * concurrent process bundle requests. (Note that all SDKs must process
     * an unbounded number of concurrent process bundle requests; this capability
     * simply indicates this SDK can actually parallelize the work across multiple
     * cores.
     *
     * @generated from protobuf enum value: MULTI_CORE_BUNDLE_PROCESSING = 3;
     */
    MULTI_CORE_BUNDLE_PROCESSING = 3,
    /**
     * Indicates this SDK can cheaply spawn sibling workers (e.g. within the
     * same container) to work around the fact that it cannot take advantage
     * of multiple cores (i.e. MULTI_CORE_BUNDLE_PROCESSING is not set).
     *
     * @generated from protobuf enum value: SIBLING_WORKERS = 5;
     */
    SIBLING_WORKERS = 5,
    /**
     * Indicates that this SDK handles the InstructionRequest of type
     * HarnessMonitoringInfosRequest.
     * A request to provide full MonitoringInfo data associated with
     * the entire SDK harness process, not specific to a bundle.
     *
     * @generated from protobuf enum value: HARNESS_MONITORING_INFOS = 4;
     */
    HARNESS_MONITORING_INFOS = 4,
    /**
     * Indicates that this SDK can process elements embedded in the
     * ProcessBundleRequest. See more about the protocol at
     * https://s.apache.org/beam-fn-api-control-data-embedding
     *
     * @generated from protobuf enum value: CONTROL_REQUEST_ELEMENTS_EMBEDDING = 6;
     */
    CONTROL_REQUEST_ELEMENTS_EMBEDDING = 6,
    /**
     * Indicates that this SDK can cache user state and side inputs across
     * bundle boundaries. This is a hint to runners that runners can rely on the
     * SDKs ability to store the data in memory reducing the amount of memory
     * used overall.
     *
     * @generated from protobuf enum value: STATE_CACHING = 7;
     */
    STATE_CACHING = 7
}
/**
 * These URNs are used to indicate capabilities of runner that an environment
 * may take advantage of when interacting with this runner.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.StandardRunnerProtocols
 */
export interface StandardRunnerProtocols {
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.StandardRunnerProtocols.Enum
 */
export declare enum StandardRunnerProtocols_Enum {
    /**
     * Indicates suport the MonitoringInfo short id protocol.
     *
     * @generated from protobuf enum value: MONITORING_INFO_SHORT_IDS = 0;
     */
    MONITORING_INFO_SHORT_IDS = 0,
    /**
     * Indicates that this runner can process elements embedded in the
     * ProcessBundleResponse. See more about the protocol at
     * https://s.apache.org/beam-fn-api-control-data-embedding
     *
     * @generated from protobuf enum value: CONTROL_RESPONSE_ELEMENTS_EMBEDDING = 6;
     */
    CONTROL_RESPONSE_ELEMENTS_EMBEDDING = 6
}
/**
 * These URNs are used to indicate requirements of a pipeline that cannot
 * simply be expressed as a component (such as a Coder or PTransform) that the
 * runner must understand. In many cases, this indicates a particular field
 * of a transform must be inspected and respected (which allows new fields
 * to be added in a forwards-compatible way).
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.StandardRequirements
 */
export interface StandardRequirements {
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.StandardRequirements.Enum
 */
export declare enum StandardRequirements_Enum {
    /**
     * This requirement indicates the state_specs and timer_family_specs fields of ParDo
     * transform payloads must be inspected.
     *
     * @generated from protobuf enum value: REQUIRES_STATEFUL_PROCESSING = 0;
     */
    REQUIRES_STATEFUL_PROCESSING = 0,
    /**
     * This requirement indicates the requests_finalization field of ParDo
     * transform payloads must be inspected.
     *
     * @generated from protobuf enum value: REQUIRES_BUNDLE_FINALIZATION = 1;
     */
    REQUIRES_BUNDLE_FINALIZATION = 1,
    /**
     * This requirement indicates the requires_stable_input field of ParDo
     * transform payloads must be inspected.
     *
     * @generated from protobuf enum value: REQUIRES_STABLE_INPUT = 2;
     */
    REQUIRES_STABLE_INPUT = 2,
    /**
     * This requirement indicates the requires_time_sorted_input field of ParDo
     * transform payloads must be inspected.
     *
     * @generated from protobuf enum value: REQUIRES_TIME_SORTED_INPUT = 3;
     */
    REQUIRES_TIME_SORTED_INPUT = 3,
    /**
     * This requirement indicates the restriction_coder_id field of ParDo
     * transform payloads must be inspected.
     *
     * @generated from protobuf enum value: REQUIRES_SPLITTABLE_DOFN = 4;
     */
    REQUIRES_SPLITTABLE_DOFN = 4,
    /**
     * This requirement indicates that the on_window_expiration_timer_family_spec field
     * of ParDo transform payloads must be inspected.
     *
     * @generated from protobuf enum value: REQUIRES_ON_WINDOW_EXPIRATION = 5;
     */
    REQUIRES_ON_WINDOW_EXPIRATION = 5
}
/**
 * A URN along with a parameter object whose schema is determined by the
 * URN.
 *
 * This structure is reused in two distinct, but compatible, ways:
 *
 * 1. This can be a specification of the function over PCollections
 *    that a PTransform computes.
 * 2. This can be a specification of a user-defined function, possibly
 *    SDK-specific. (external to this message must be adequate context
 *    to indicate the environment in which the UDF can be understood).
 *
 * Though not explicit in this proto, there are two possibilities
 * for the relationship of a runner to this specification that
 * one should bear in mind:
 *
 * 1. The runner understands the URN. For example, it might be
 *    a well-known URN like "beam:transform:Top" or
 *    "beam:window_fn:FixedWindows" with
 *    an agreed-upon payload (e.g. a number or duration,
 *    respectively).
 * 2. The runner does not understand the URN. It might be an
 *    SDK specific URN such as "beam:dofn:javasdk:1.0"
 *    that indicates to the SDK what the payload is,
 *    such as a serialized Java DoFn from a particular
 *    version of the Beam Java SDK. The payload will often
 *    then be an opaque message such as bytes in a
 *    language-specific serialization format.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.FunctionSpec
 */
export interface FunctionSpec {
    /**
     * (Required) A URN that describes the accompanying payload.
     * For any URN that is not recognized (by whomever is inspecting
     * it) the parameter payload should be treated as opaque and
     * passed as-is.
     *
     * @generated from protobuf field: string urn = 1;
     */
    urn: string;
    /**
     * (Optional) The data specifying any parameters to the URN. If
     * the URN does not require any arguments, this may be omitted.
     *
     * @generated from protobuf field: bytes payload = 3;
     */
    payload: Uint8Array;
}
/**
 * A set of well known URNs describing display data.
 *
 * All descriptions must contain how the value should be classified and how it
 * is encoded. Note that some types are logical types which convey contextual
 * information about the pipeline in addition to an encoding while others only
 * specify the encoding itself.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.StandardDisplayData
 */
export interface StandardDisplayData {
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.StandardDisplayData.DisplayData
 */
export declare enum StandardDisplayData_DisplayData {
    /**
     * A string label and value. Has a payload containing an encoded
     * LabelledPayload.
     *
     * @generated from protobuf enum value: LABELLED = 0;
     */
    LABELLED = 0
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.LabelledPayload
 */
export interface LabelledPayload {
    /**
     * (Required) A human readable label for the value.
     *
     * @generated from protobuf field: string label = 1;
     */
    label: string;
    /**
     * @generated from protobuf oneof: value
     */
    value: {
        oneofKind: "stringValue";
        /**
         * @generated from protobuf field: string string_value = 2;
         */
        stringValue: string;
    } | {
        oneofKind: "boolValue";
        /**
         * @generated from protobuf field: bool bool_value = 3;
         */
        boolValue: boolean;
    } | {
        oneofKind: "doubleValue";
        /**
         * @generated from protobuf field: double double_value = 4;
         */
        doubleValue: number;
    } | {
        oneofKind: "intValue";
        /**
         * @generated from protobuf field: int64 int_value = 5;
         */
        intValue: bigint;
    } | {
        oneofKind: undefined;
    };
    /**
     * (Required) The key identifies the actual content of the metadata.
     *
     * @generated from protobuf field: string key = 6;
     */
    key: string;
    /**
     * (Required) The namespace describes the context that specified the key.
     *
     * @generated from protobuf field: string namespace = 7;
     */
    namespace: string;
}
/**
 * Static display data associated with a pipeline component. Display data is
 * useful for pipeline runners IOs and diagnostic dashboards to display details
 * about annotated components.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.DisplayData
 */
export interface DisplayData {
    /**
     * A key used to describe the type of display data. See StandardDisplayData
     * for the set of well known urns describing how the payload is meant to be
     * interpreted.
     *
     * @generated from protobuf field: string urn = 1;
     */
    urn: string;
    /**
     * (Optional) The data specifying any parameters to the URN. If
     * the URN does not require any arguments, this may be omitted.
     *
     * @generated from protobuf field: bytes payload = 2;
     */
    payload: Uint8Array;
}
/**
 * A disjoint union of all the things that may contain references
 * that require Components to resolve.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.MessageWithComponents
 */
export interface MessageWithComponents {
    /**
     * (Optional) The by-reference components of the root message,
     * enabling a standalone message.
     *
     * If this is absent, it is expected that there are no
     * references.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Components components = 1;
     */
    components?: Components;
    /**
     * @generated from protobuf oneof: root
     */
    root: {
        oneofKind: "coder";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Coder coder = 2;
         */
        coder: Coder;
    } | {
        oneofKind: "combinePayload";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.CombinePayload combine_payload = 3;
         */
        combinePayload: CombinePayload;
    } | {
        oneofKind: "functionSpec";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.FunctionSpec function_spec = 4;
         */
        functionSpec: FunctionSpec;
    } | {
        oneofKind: "parDoPayload";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.ParDoPayload par_do_payload = 6;
         */
        parDoPayload: ParDoPayload;
    } | {
        oneofKind: "ptransform";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.PTransform ptransform = 7;
         */
        ptransform: PTransform;
    } | {
        oneofKind: "pcollection";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.PCollection pcollection = 8;
         */
        pcollection: PCollection;
    } | {
        oneofKind: "readPayload";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.ReadPayload read_payload = 9;
         */
        readPayload: ReadPayload;
    } | {
        oneofKind: "sideInput";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.SideInput side_input = 11;
         */
        sideInput: SideInput;
    } | {
        oneofKind: "windowIntoPayload";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.WindowIntoPayload window_into_payload = 12;
         */
        windowIntoPayload: WindowIntoPayload;
    } | {
        oneofKind: "windowingStrategy";
        /**
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.WindowingStrategy windowing_strategy = 13;
         */
        windowingStrategy: WindowingStrategy;
    } | {
        oneofKind: undefined;
    };
}
/**
 * The payload for an executable stage. This will eventually be passed to an SDK in the form of a
 * ProcessBundleDescriptor.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.ExecutableStagePayload
 */
export interface ExecutableStagePayload {
    /**
     * (Required) Environment in which this stage executes.
     *
     * We use an environment rather than environment id
     * because ExecutableStages use environments directly. This may change in the future.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Environment environment = 1;
     */
    environment?: Environment;
    /**
     * The wire coder settings of this executable stage
     *
     * @generated from protobuf field: repeated org.apache.beam.model.pipeline.v1.ExecutableStagePayload.WireCoderSetting wire_coder_settings = 9;
     */
    wireCoderSettings: ExecutableStagePayload_WireCoderSetting[];
    /**
     * (Required) Input PCollection id. This must be present as a value in the inputs of any
     * PTransform the ExecutableStagePayload is the payload of.
     *
     * @generated from protobuf field: string input = 2;
     */
    input: string;
    /**
     * The side inputs required for this executable stage. Each side input of each PTransform within
     * this ExecutableStagePayload must be represented within this field.
     *
     * @generated from protobuf field: repeated org.apache.beam.model.pipeline.v1.ExecutableStagePayload.SideInputId side_inputs = 3;
     */
    sideInputs: ExecutableStagePayload_SideInputId[];
    /**
     * PTransform ids contained within this executable stage. This must contain at least one
     * PTransform id.
     *
     * @generated from protobuf field: repeated string transforms = 4;
     */
    transforms: string[];
    /**
     * Output PCollection ids. This must be equal to the values of the outputs of any
     * PTransform the ExecutableStagePayload is the payload of.
     *
     * @generated from protobuf field: repeated string outputs = 5;
     */
    outputs: string[];
    /**
     * (Required) The components for the Executable Stage. This must contain all of the Transforms
     * in transforms, and the closure of all of the components they recognize.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Components components = 6;
     */
    components?: Components;
    /**
     * The user states required for this executable stage. Each user state of each PTransform within
     * this ExecutableStagePayload must be represented within this field.
     *
     * @generated from protobuf field: repeated org.apache.beam.model.pipeline.v1.ExecutableStagePayload.UserStateId user_states = 7;
     */
    userStates: ExecutableStagePayload_UserStateId[];
    /**
     * The timers required for this executable stage. Each timer of each PTransform within
     * this ExecutableStagePayload must be represented within this field.
     *
     * @generated from protobuf field: repeated org.apache.beam.model.pipeline.v1.ExecutableStagePayload.TimerId timers = 8;
     */
    timers: ExecutableStagePayload_TimerId[];
    /**
     * The timerfamilies required for this executable stage. Each timer familyof each PTransform within
     * this ExecutableStagePayload must be represented within this field.
     *
     * @generated from protobuf field: repeated org.apache.beam.model.pipeline.v1.ExecutableStagePayload.TimerFamilyId timerFamilies = 10;
     */
    timerFamilies: ExecutableStagePayload_TimerFamilyId[];
}
/**
 * A reference to a side input. Side inputs are uniquely identified by PTransform id and
 * local name.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.ExecutableStagePayload.SideInputId
 */
export interface ExecutableStagePayload_SideInputId {
    /**
     * (Required) The id of the PTransform that references this side input.
     *
     * @generated from protobuf field: string transform_id = 1;
     */
    transformId: string;
    /**
     * (Required) The local name of this side input from the PTransform that references it.
     *
     * @generated from protobuf field: string local_name = 2;
     */
    localName: string;
}
/**
 * A reference to user state. User states are uniquely identified by PTransform id and
 * local name.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.ExecutableStagePayload.UserStateId
 */
export interface ExecutableStagePayload_UserStateId {
    /**
     * (Required) The id of the PTransform that references this user state.
     *
     * @generated from protobuf field: string transform_id = 1;
     */
    transformId: string;
    /**
     * (Required) The local name of this user state for the PTransform that references it.
     *
     * @generated from protobuf field: string local_name = 2;
     */
    localName: string;
}
/**
 * A reference to a timer. Timers are uniquely identified by PTransform id and
 * local name.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.ExecutableStagePayload.TimerId
 */
export interface ExecutableStagePayload_TimerId {
    /**
     * (Required) The id of the PTransform that references this timer.
     *
     * @generated from protobuf field: string transform_id = 1;
     */
    transformId: string;
    /**
     * (Required) The local name of this timer for the PTransform that references it.
     *
     * @generated from protobuf field: string local_name = 2;
     */
    localName: string;
}
/**
 * A reference to a timer. Timers are uniquely identified by PTransform id and
 * local name.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.ExecutableStagePayload.TimerFamilyId
 */
export interface ExecutableStagePayload_TimerFamilyId {
    /**
     * (Required) The id of the PTransform that references this timer family.
     *
     * @generated from protobuf field: string transform_id = 1;
     */
    transformId: string;
    /**
     * (Required) The local name of this timer family for the PTransform that references it.
     *
     * @generated from protobuf field: string local_name = 2;
     */
    localName: string;
}
/**
 * Settings that decide the coder type of wire coder.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.ExecutableStagePayload.WireCoderSetting
 */
export interface ExecutableStagePayload_WireCoderSetting {
    /**
     * (Required) The URN of the wire coder.
     * Note that only windowed value coder or parameterized windowed value coder are supported.
     *
     * @generated from protobuf field: string urn = 1;
     */
    urn: string;
    /**
     * (Optional) The data specifying any parameters to the URN. If
     * the URN is beam:coder:windowed_value:v1, this may be omitted. If the URN is
     * beam:coder:param_windowed_value:v1, the payload is an encoded windowed
     * value using the beam:coder:windowed_value:v1 coder parameterized by
     * a beam:coder:bytes:v1 element coder and the window coder that this
     * param_windowed_value coder uses.
     *
     * @generated from protobuf field: bytes payload = 2;
     */
    payload: Uint8Array;
    /**
     * @generated from protobuf oneof: target
     */
    target: {
        oneofKind: "inputOrOutputId";
        /**
         * The input or output PCollection id this setting applies to.
         *
         * @generated from protobuf field: string input_or_output_id = 3;
         */
        inputOrOutputId: string;
    } | {
        oneofKind: "timer";
        /**
         * The timer id this setting applies to.
         *
         * @generated from protobuf field: org.apache.beam.model.pipeline.v1.ExecutableStagePayload.TimerId timer = 4;
         */
        timer: ExecutableStagePayload_TimerId;
    } | {
        oneofKind: undefined;
    };
}
/**
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.StandardResourceHints
 */
export interface StandardResourceHints {
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.StandardResourceHints.Enum
 */
export declare enum StandardResourceHints_Enum {
    /**
     * Describes hardware accelerators that are desired to have in the execution environment.
     *
     * @generated from protobuf enum value: ACCELERATOR = 0;
     */
    ACCELERATOR = 0,
    /**
     * Describes desired minimal available RAM size in transform's execution environment.
     * SDKs should convert the size to bytes, but can allow users to specify human-friendly units (e.g. GiB).
     *
     * @generated from protobuf enum value: MIN_RAM_BYTES = 1;
     */
    MIN_RAM_BYTES = 1
}
declare class BeamConstants$Type extends MessageType<BeamConstants> {
    constructor();
    create(value?: PartialMessage<BeamConstants>): BeamConstants;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: BeamConstants): BeamConstants;
    internalBinaryWrite(message: BeamConstants, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.BeamConstants
 */
export declare const BeamConstants: BeamConstants$Type;
declare class Components$Type extends MessageType<Components> {
    constructor();
    create(value?: PartialMessage<Components>): Components;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: Components): Components;
    private binaryReadMap1;
    private binaryReadMap2;
    private binaryReadMap3;
    private binaryReadMap4;
    private binaryReadMap5;
    internalBinaryWrite(message: Components, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.Components
 */
export declare const Components: Components$Type;
declare class Pipeline$Type extends MessageType<Pipeline> {
    constructor();
    create(value?: PartialMessage<Pipeline>): Pipeline;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: Pipeline): Pipeline;
    internalBinaryWrite(message: Pipeline, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.Pipeline
 */
export declare const Pipeline: Pipeline$Type;
declare class PTransform$Type extends MessageType<PTransform> {
    constructor();
    create(value?: PartialMessage<PTransform>): PTransform;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: PTransform): PTransform;
    private binaryReadMap3;
    private binaryReadMap4;
    private binaryReadMap8;
    internalBinaryWrite(message: PTransform, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.PTransform
 */
export declare const PTransform: PTransform$Type;
declare class StandardPTransforms$Type extends MessageType<StandardPTransforms> {
    constructor();
    create(value?: PartialMessage<StandardPTransforms>): StandardPTransforms;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: StandardPTransforms): StandardPTransforms;
    internalBinaryWrite(message: StandardPTransforms, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.StandardPTransforms
 */
export declare const StandardPTransforms: StandardPTransforms$Type;
declare class StandardSideInputTypes$Type extends MessageType<StandardSideInputTypes> {
    constructor();
    create(value?: PartialMessage<StandardSideInputTypes>): StandardSideInputTypes;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: StandardSideInputTypes): StandardSideInputTypes;
    internalBinaryWrite(message: StandardSideInputTypes, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.StandardSideInputTypes
 */
export declare const StandardSideInputTypes: StandardSideInputTypes$Type;
declare class StandardUserStateTypes$Type extends MessageType<StandardUserStateTypes> {
    constructor();
    create(value?: PartialMessage<StandardUserStateTypes>): StandardUserStateTypes;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: StandardUserStateTypes): StandardUserStateTypes;
    internalBinaryWrite(message: StandardUserStateTypes, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.StandardUserStateTypes
 */
export declare const StandardUserStateTypes: StandardUserStateTypes$Type;
declare class PCollection$Type extends MessageType<PCollection> {
    constructor();
    create(value?: PartialMessage<PCollection>): PCollection;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: PCollection): PCollection;
    internalBinaryWrite(message: PCollection, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.PCollection
 */
export declare const PCollection: PCollection$Type;
declare class ParDoPayload$Type extends MessageType<ParDoPayload> {
    constructor();
    create(value?: PartialMessage<ParDoPayload>): ParDoPayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ParDoPayload): ParDoPayload;
    private binaryReadMap3;
    private binaryReadMap4;
    private binaryReadMap9;
    internalBinaryWrite(message: ParDoPayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.ParDoPayload
 */
export declare const ParDoPayload: ParDoPayload$Type;
declare class StateSpec$Type extends MessageType<StateSpec> {
    constructor();
    create(value?: PartialMessage<StateSpec>): StateSpec;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: StateSpec): StateSpec;
    internalBinaryWrite(message: StateSpec, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.StateSpec
 */
export declare const StateSpec: StateSpec$Type;
declare class ReadModifyWriteStateSpec$Type extends MessageType<ReadModifyWriteStateSpec> {
    constructor();
    create(value?: PartialMessage<ReadModifyWriteStateSpec>): ReadModifyWriteStateSpec;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ReadModifyWriteStateSpec): ReadModifyWriteStateSpec;
    internalBinaryWrite(message: ReadModifyWriteStateSpec, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.ReadModifyWriteStateSpec
 */
export declare const ReadModifyWriteStateSpec: ReadModifyWriteStateSpec$Type;
declare class BagStateSpec$Type extends MessageType<BagStateSpec> {
    constructor();
    create(value?: PartialMessage<BagStateSpec>): BagStateSpec;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: BagStateSpec): BagStateSpec;
    internalBinaryWrite(message: BagStateSpec, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.BagStateSpec
 */
export declare const BagStateSpec: BagStateSpec$Type;
declare class OrderedListStateSpec$Type extends MessageType<OrderedListStateSpec> {
    constructor();
    create(value?: PartialMessage<OrderedListStateSpec>): OrderedListStateSpec;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: OrderedListStateSpec): OrderedListStateSpec;
    internalBinaryWrite(message: OrderedListStateSpec, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.OrderedListStateSpec
 */
export declare const OrderedListStateSpec: OrderedListStateSpec$Type;
declare class CombiningStateSpec$Type extends MessageType<CombiningStateSpec> {
    constructor();
    create(value?: PartialMessage<CombiningStateSpec>): CombiningStateSpec;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: CombiningStateSpec): CombiningStateSpec;
    internalBinaryWrite(message: CombiningStateSpec, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.CombiningStateSpec
 */
export declare const CombiningStateSpec: CombiningStateSpec$Type;
declare class MapStateSpec$Type extends MessageType<MapStateSpec> {
    constructor();
    create(value?: PartialMessage<MapStateSpec>): MapStateSpec;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: MapStateSpec): MapStateSpec;
    internalBinaryWrite(message: MapStateSpec, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.MapStateSpec
 */
export declare const MapStateSpec: MapStateSpec$Type;
declare class SetStateSpec$Type extends MessageType<SetStateSpec> {
    constructor();
    create(value?: PartialMessage<SetStateSpec>): SetStateSpec;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: SetStateSpec): SetStateSpec;
    internalBinaryWrite(message: SetStateSpec, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.SetStateSpec
 */
export declare const SetStateSpec: SetStateSpec$Type;
declare class TimerFamilySpec$Type extends MessageType<TimerFamilySpec> {
    constructor();
    create(value?: PartialMessage<TimerFamilySpec>): TimerFamilySpec;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: TimerFamilySpec): TimerFamilySpec;
    internalBinaryWrite(message: TimerFamilySpec, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.TimerFamilySpec
 */
export declare const TimerFamilySpec: TimerFamilySpec$Type;
declare class IsBounded$Type extends MessageType<IsBounded> {
    constructor();
    create(value?: PartialMessage<IsBounded>): IsBounded;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: IsBounded): IsBounded;
    internalBinaryWrite(message: IsBounded, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.IsBounded
 */
export declare const IsBounded: IsBounded$Type;
declare class ReadPayload$Type extends MessageType<ReadPayload> {
    constructor();
    create(value?: PartialMessage<ReadPayload>): ReadPayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ReadPayload): ReadPayload;
    internalBinaryWrite(message: ReadPayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.ReadPayload
 */
export declare const ReadPayload: ReadPayload$Type;
declare class WindowIntoPayload$Type extends MessageType<WindowIntoPayload> {
    constructor();
    create(value?: PartialMessage<WindowIntoPayload>): WindowIntoPayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: WindowIntoPayload): WindowIntoPayload;
    internalBinaryWrite(message: WindowIntoPayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.WindowIntoPayload
 */
export declare const WindowIntoPayload: WindowIntoPayload$Type;
declare class CombinePayload$Type extends MessageType<CombinePayload> {
    constructor();
    create(value?: PartialMessage<CombinePayload>): CombinePayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: CombinePayload): CombinePayload;
    internalBinaryWrite(message: CombinePayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.CombinePayload
 */
export declare const CombinePayload: CombinePayload$Type;
declare class TestStreamPayload$Type extends MessageType<TestStreamPayload> {
    constructor();
    create(value?: PartialMessage<TestStreamPayload>): TestStreamPayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: TestStreamPayload): TestStreamPayload;
    internalBinaryWrite(message: TestStreamPayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.TestStreamPayload
 */
export declare const TestStreamPayload: TestStreamPayload$Type;
declare class TestStreamPayload_Event$Type extends MessageType<TestStreamPayload_Event> {
    constructor();
    create(value?: PartialMessage<TestStreamPayload_Event>): TestStreamPayload_Event;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: TestStreamPayload_Event): TestStreamPayload_Event;
    internalBinaryWrite(message: TestStreamPayload_Event, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.TestStreamPayload.Event
 */
export declare const TestStreamPayload_Event: TestStreamPayload_Event$Type;
declare class TestStreamPayload_Event_AdvanceWatermark$Type extends MessageType<TestStreamPayload_Event_AdvanceWatermark> {
    constructor();
    create(value?: PartialMessage<TestStreamPayload_Event_AdvanceWatermark>): TestStreamPayload_Event_AdvanceWatermark;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: TestStreamPayload_Event_AdvanceWatermark): TestStreamPayload_Event_AdvanceWatermark;
    internalBinaryWrite(message: TestStreamPayload_Event_AdvanceWatermark, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.TestStreamPayload.Event.AdvanceWatermark
 */
export declare const TestStreamPayload_Event_AdvanceWatermark: TestStreamPayload_Event_AdvanceWatermark$Type;
declare class TestStreamPayload_Event_AdvanceProcessingTime$Type extends MessageType<TestStreamPayload_Event_AdvanceProcessingTime> {
    constructor();
    create(value?: PartialMessage<TestStreamPayload_Event_AdvanceProcessingTime>): TestStreamPayload_Event_AdvanceProcessingTime;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: TestStreamPayload_Event_AdvanceProcessingTime): TestStreamPayload_Event_AdvanceProcessingTime;
    internalBinaryWrite(message: TestStreamPayload_Event_AdvanceProcessingTime, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.TestStreamPayload.Event.AdvanceProcessingTime
 */
export declare const TestStreamPayload_Event_AdvanceProcessingTime: TestStreamPayload_Event_AdvanceProcessingTime$Type;
declare class TestStreamPayload_Event_AddElements$Type extends MessageType<TestStreamPayload_Event_AddElements> {
    constructor();
    create(value?: PartialMessage<TestStreamPayload_Event_AddElements>): TestStreamPayload_Event_AddElements;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: TestStreamPayload_Event_AddElements): TestStreamPayload_Event_AddElements;
    internalBinaryWrite(message: TestStreamPayload_Event_AddElements, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.TestStreamPayload.Event.AddElements
 */
export declare const TestStreamPayload_Event_AddElements: TestStreamPayload_Event_AddElements$Type;
declare class TestStreamPayload_TimestampedElement$Type extends MessageType<TestStreamPayload_TimestampedElement> {
    constructor();
    create(value?: PartialMessage<TestStreamPayload_TimestampedElement>): TestStreamPayload_TimestampedElement;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: TestStreamPayload_TimestampedElement): TestStreamPayload_TimestampedElement;
    internalBinaryWrite(message: TestStreamPayload_TimestampedElement, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.TestStreamPayload.TimestampedElement
 */
export declare const TestStreamPayload_TimestampedElement: TestStreamPayload_TimestampedElement$Type;
declare class EventsRequest$Type extends MessageType<EventsRequest> {
    constructor();
    create(value?: PartialMessage<EventsRequest>): EventsRequest;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: EventsRequest): EventsRequest;
    internalBinaryWrite(message: EventsRequest, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.EventsRequest
 */
export declare const EventsRequest: EventsRequest$Type;
declare class WriteFilesPayload$Type extends MessageType<WriteFilesPayload> {
    constructor();
    create(value?: PartialMessage<WriteFilesPayload>): WriteFilesPayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: WriteFilesPayload): WriteFilesPayload;
    private binaryReadMap5;
    internalBinaryWrite(message: WriteFilesPayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.WriteFilesPayload
 */
export declare const WriteFilesPayload: WriteFilesPayload$Type;
declare class PubSubReadPayload$Type extends MessageType<PubSubReadPayload> {
    constructor();
    create(value?: PartialMessage<PubSubReadPayload>): PubSubReadPayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: PubSubReadPayload): PubSubReadPayload;
    internalBinaryWrite(message: PubSubReadPayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.PubSubReadPayload
 */
export declare const PubSubReadPayload: PubSubReadPayload$Type;
declare class PubSubWritePayload$Type extends MessageType<PubSubWritePayload> {
    constructor();
    create(value?: PartialMessage<PubSubWritePayload>): PubSubWritePayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: PubSubWritePayload): PubSubWritePayload;
    internalBinaryWrite(message: PubSubWritePayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.PubSubWritePayload
 */
export declare const PubSubWritePayload: PubSubWritePayload$Type;
declare class GroupIntoBatchesPayload$Type extends MessageType<GroupIntoBatchesPayload> {
    constructor();
    create(value?: PartialMessage<GroupIntoBatchesPayload>): GroupIntoBatchesPayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: GroupIntoBatchesPayload): GroupIntoBatchesPayload;
    internalBinaryWrite(message: GroupIntoBatchesPayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.GroupIntoBatchesPayload
 */
export declare const GroupIntoBatchesPayload: GroupIntoBatchesPayload$Type;
declare class Coder$Type extends MessageType<Coder> {
    constructor();
    create(value?: PartialMessage<Coder>): Coder;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: Coder): Coder;
    internalBinaryWrite(message: Coder, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.Coder
 */
export declare const Coder: Coder$Type;
declare class StandardCoders$Type extends MessageType<StandardCoders> {
    constructor();
    create(value?: PartialMessage<StandardCoders>): StandardCoders;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: StandardCoders): StandardCoders;
    internalBinaryWrite(message: StandardCoders, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.StandardCoders
 */
export declare const StandardCoders: StandardCoders$Type;
declare class WindowingStrategy$Type extends MessageType<WindowingStrategy> {
    constructor();
    create(value?: PartialMessage<WindowingStrategy>): WindowingStrategy;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: WindowingStrategy): WindowingStrategy;
    internalBinaryWrite(message: WindowingStrategy, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.WindowingStrategy
 */
export declare const WindowingStrategy: WindowingStrategy$Type;
declare class MergeStatus$Type extends MessageType<MergeStatus> {
    constructor();
    create(value?: PartialMessage<MergeStatus>): MergeStatus;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: MergeStatus): MergeStatus;
    internalBinaryWrite(message: MergeStatus, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.MergeStatus
 */
export declare const MergeStatus: MergeStatus$Type;
declare class AccumulationMode$Type extends MessageType<AccumulationMode> {
    constructor();
    create(value?: PartialMessage<AccumulationMode>): AccumulationMode;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: AccumulationMode): AccumulationMode;
    internalBinaryWrite(message: AccumulationMode, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.AccumulationMode
 */
export declare const AccumulationMode: AccumulationMode$Type;
declare class ClosingBehavior$Type extends MessageType<ClosingBehavior> {
    constructor();
    create(value?: PartialMessage<ClosingBehavior>): ClosingBehavior;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ClosingBehavior): ClosingBehavior;
    internalBinaryWrite(message: ClosingBehavior, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.ClosingBehavior
 */
export declare const ClosingBehavior: ClosingBehavior$Type;
declare class OnTimeBehavior$Type extends MessageType<OnTimeBehavior> {
    constructor();
    create(value?: PartialMessage<OnTimeBehavior>): OnTimeBehavior;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: OnTimeBehavior): OnTimeBehavior;
    internalBinaryWrite(message: OnTimeBehavior, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.OnTimeBehavior
 */
export declare const OnTimeBehavior: OnTimeBehavior$Type;
declare class OutputTime$Type extends MessageType<OutputTime> {
    constructor();
    create(value?: PartialMessage<OutputTime>): OutputTime;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: OutputTime): OutputTime;
    internalBinaryWrite(message: OutputTime, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.OutputTime
 */
export declare const OutputTime: OutputTime$Type;
declare class TimeDomain$Type extends MessageType<TimeDomain> {
    constructor();
    create(value?: PartialMessage<TimeDomain>): TimeDomain;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: TimeDomain): TimeDomain;
    internalBinaryWrite(message: TimeDomain, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.TimeDomain
 */
export declare const TimeDomain: TimeDomain$Type;
declare class Trigger$Type extends MessageType<Trigger> {
    constructor();
    create(value?: PartialMessage<Trigger>): Trigger;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: Trigger): Trigger;
    internalBinaryWrite(message: Trigger, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.Trigger
 */
export declare const Trigger: Trigger$Type;
declare class Trigger_AfterAll$Type extends MessageType<Trigger_AfterAll> {
    constructor();
    create(value?: PartialMessage<Trigger_AfterAll>): Trigger_AfterAll;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: Trigger_AfterAll): Trigger_AfterAll;
    internalBinaryWrite(message: Trigger_AfterAll, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.Trigger.AfterAll
 */
export declare const Trigger_AfterAll: Trigger_AfterAll$Type;
declare class Trigger_AfterAny$Type extends MessageType<Trigger_AfterAny> {
    constructor();
    create(value?: PartialMessage<Trigger_AfterAny>): Trigger_AfterAny;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: Trigger_AfterAny): Trigger_AfterAny;
    internalBinaryWrite(message: Trigger_AfterAny, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.Trigger.AfterAny
 */
export declare const Trigger_AfterAny: Trigger_AfterAny$Type;
declare class Trigger_AfterEach$Type extends MessageType<Trigger_AfterEach> {
    constructor();
    create(value?: PartialMessage<Trigger_AfterEach>): Trigger_AfterEach;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: Trigger_AfterEach): Trigger_AfterEach;
    internalBinaryWrite(message: Trigger_AfterEach, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.Trigger.AfterEach
 */
export declare const Trigger_AfterEach: Trigger_AfterEach$Type;
declare class Trigger_AfterEndOfWindow$Type extends MessageType<Trigger_AfterEndOfWindow> {
    constructor();
    create(value?: PartialMessage<Trigger_AfterEndOfWindow>): Trigger_AfterEndOfWindow;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: Trigger_AfterEndOfWindow): Trigger_AfterEndOfWindow;
    internalBinaryWrite(message: Trigger_AfterEndOfWindow, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.Trigger.AfterEndOfWindow
 */
export declare const Trigger_AfterEndOfWindow: Trigger_AfterEndOfWindow$Type;
declare class Trigger_AfterProcessingTime$Type extends MessageType<Trigger_AfterProcessingTime> {
    constructor();
    create(value?: PartialMessage<Trigger_AfterProcessingTime>): Trigger_AfterProcessingTime;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: Trigger_AfterProcessingTime): Trigger_AfterProcessingTime;
    internalBinaryWrite(message: Trigger_AfterProcessingTime, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.Trigger.AfterProcessingTime
 */
export declare const Trigger_AfterProcessingTime: Trigger_AfterProcessingTime$Type;
declare class Trigger_AfterSynchronizedProcessingTime$Type extends MessageType<Trigger_AfterSynchronizedProcessingTime> {
    constructor();
    create(value?: PartialMessage<Trigger_AfterSynchronizedProcessingTime>): Trigger_AfterSynchronizedProcessingTime;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: Trigger_AfterSynchronizedProcessingTime): Trigger_AfterSynchronizedProcessingTime;
    internalBinaryWrite(message: Trigger_AfterSynchronizedProcessingTime, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.Trigger.AfterSynchronizedProcessingTime
 */
export declare const Trigger_AfterSynchronizedProcessingTime: Trigger_AfterSynchronizedProcessingTime$Type;
declare class Trigger_Default$Type extends MessageType<Trigger_Default> {
    constructor();
    create(value?: PartialMessage<Trigger_Default>): Trigger_Default;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: Trigger_Default): Trigger_Default;
    internalBinaryWrite(message: Trigger_Default, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.Trigger.Default
 */
export declare const Trigger_Default: Trigger_Default$Type;
declare class Trigger_ElementCount$Type extends MessageType<Trigger_ElementCount> {
    constructor();
    create(value?: PartialMessage<Trigger_ElementCount>): Trigger_ElementCount;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: Trigger_ElementCount): Trigger_ElementCount;
    internalBinaryWrite(message: Trigger_ElementCount, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.Trigger.ElementCount
 */
export declare const Trigger_ElementCount: Trigger_ElementCount$Type;
declare class Trigger_Never$Type extends MessageType<Trigger_Never> {
    constructor();
    create(value?: PartialMessage<Trigger_Never>): Trigger_Never;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: Trigger_Never): Trigger_Never;
    internalBinaryWrite(message: Trigger_Never, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.Trigger.Never
 */
export declare const Trigger_Never: Trigger_Never$Type;
declare class Trigger_Always$Type extends MessageType<Trigger_Always> {
    constructor();
    create(value?: PartialMessage<Trigger_Always>): Trigger_Always;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: Trigger_Always): Trigger_Always;
    internalBinaryWrite(message: Trigger_Always, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.Trigger.Always
 */
export declare const Trigger_Always: Trigger_Always$Type;
declare class Trigger_OrFinally$Type extends MessageType<Trigger_OrFinally> {
    constructor();
    create(value?: PartialMessage<Trigger_OrFinally>): Trigger_OrFinally;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: Trigger_OrFinally): Trigger_OrFinally;
    internalBinaryWrite(message: Trigger_OrFinally, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.Trigger.OrFinally
 */
export declare const Trigger_OrFinally: Trigger_OrFinally$Type;
declare class Trigger_Repeat$Type extends MessageType<Trigger_Repeat> {
    constructor();
    create(value?: PartialMessage<Trigger_Repeat>): Trigger_Repeat;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: Trigger_Repeat): Trigger_Repeat;
    internalBinaryWrite(message: Trigger_Repeat, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.Trigger.Repeat
 */
export declare const Trigger_Repeat: Trigger_Repeat$Type;
declare class TimestampTransform$Type extends MessageType<TimestampTransform> {
    constructor();
    create(value?: PartialMessage<TimestampTransform>): TimestampTransform;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: TimestampTransform): TimestampTransform;
    internalBinaryWrite(message: TimestampTransform, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.TimestampTransform
 */
export declare const TimestampTransform: TimestampTransform$Type;
declare class TimestampTransform_Delay$Type extends MessageType<TimestampTransform_Delay> {
    constructor();
    create(value?: PartialMessage<TimestampTransform_Delay>): TimestampTransform_Delay;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: TimestampTransform_Delay): TimestampTransform_Delay;
    internalBinaryWrite(message: TimestampTransform_Delay, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.TimestampTransform.Delay
 */
export declare const TimestampTransform_Delay: TimestampTransform_Delay$Type;
declare class TimestampTransform_AlignTo$Type extends MessageType<TimestampTransform_AlignTo> {
    constructor();
    create(value?: PartialMessage<TimestampTransform_AlignTo>): TimestampTransform_AlignTo;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: TimestampTransform_AlignTo): TimestampTransform_AlignTo;
    internalBinaryWrite(message: TimestampTransform_AlignTo, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.TimestampTransform.AlignTo
 */
export declare const TimestampTransform_AlignTo: TimestampTransform_AlignTo$Type;
declare class SideInput$Type extends MessageType<SideInput> {
    constructor();
    create(value?: PartialMessage<SideInput>): SideInput;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: SideInput): SideInput;
    internalBinaryWrite(message: SideInput, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.SideInput
 */
export declare const SideInput: SideInput$Type;
declare class StandardArtifacts$Type extends MessageType<StandardArtifacts> {
    constructor();
    create(value?: PartialMessage<StandardArtifacts>): StandardArtifacts;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: StandardArtifacts): StandardArtifacts;
    internalBinaryWrite(message: StandardArtifacts, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.StandardArtifacts
 */
export declare const StandardArtifacts: StandardArtifacts$Type;
declare class ArtifactFilePayload$Type extends MessageType<ArtifactFilePayload> {
    constructor();
    create(value?: PartialMessage<ArtifactFilePayload>): ArtifactFilePayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ArtifactFilePayload): ArtifactFilePayload;
    internalBinaryWrite(message: ArtifactFilePayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.ArtifactFilePayload
 */
export declare const ArtifactFilePayload: ArtifactFilePayload$Type;
declare class ArtifactUrlPayload$Type extends MessageType<ArtifactUrlPayload> {
    constructor();
    create(value?: PartialMessage<ArtifactUrlPayload>): ArtifactUrlPayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ArtifactUrlPayload): ArtifactUrlPayload;
    internalBinaryWrite(message: ArtifactUrlPayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.ArtifactUrlPayload
 */
export declare const ArtifactUrlPayload: ArtifactUrlPayload$Type;
declare class EmbeddedFilePayload$Type extends MessageType<EmbeddedFilePayload> {
    constructor();
    create(value?: PartialMessage<EmbeddedFilePayload>): EmbeddedFilePayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: EmbeddedFilePayload): EmbeddedFilePayload;
    internalBinaryWrite(message: EmbeddedFilePayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.EmbeddedFilePayload
 */
export declare const EmbeddedFilePayload: EmbeddedFilePayload$Type;
declare class PyPIPayload$Type extends MessageType<PyPIPayload> {
    constructor();
    create(value?: PartialMessage<PyPIPayload>): PyPIPayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: PyPIPayload): PyPIPayload;
    internalBinaryWrite(message: PyPIPayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.PyPIPayload
 */
export declare const PyPIPayload: PyPIPayload$Type;
declare class MavenPayload$Type extends MessageType<MavenPayload> {
    constructor();
    create(value?: PartialMessage<MavenPayload>): MavenPayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: MavenPayload): MavenPayload;
    internalBinaryWrite(message: MavenPayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.MavenPayload
 */
export declare const MavenPayload: MavenPayload$Type;
declare class DeferredArtifactPayload$Type extends MessageType<DeferredArtifactPayload> {
    constructor();
    create(value?: PartialMessage<DeferredArtifactPayload>): DeferredArtifactPayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: DeferredArtifactPayload): DeferredArtifactPayload;
    internalBinaryWrite(message: DeferredArtifactPayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.DeferredArtifactPayload
 */
export declare const DeferredArtifactPayload: DeferredArtifactPayload$Type;
declare class ArtifactStagingToRolePayload$Type extends MessageType<ArtifactStagingToRolePayload> {
    constructor();
    create(value?: PartialMessage<ArtifactStagingToRolePayload>): ArtifactStagingToRolePayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ArtifactStagingToRolePayload): ArtifactStagingToRolePayload;
    internalBinaryWrite(message: ArtifactStagingToRolePayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.ArtifactStagingToRolePayload
 */
export declare const ArtifactStagingToRolePayload: ArtifactStagingToRolePayload$Type;
declare class ArtifactInformation$Type extends MessageType<ArtifactInformation> {
    constructor();
    create(value?: PartialMessage<ArtifactInformation>): ArtifactInformation;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ArtifactInformation): ArtifactInformation;
    internalBinaryWrite(message: ArtifactInformation, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.ArtifactInformation
 */
export declare const ArtifactInformation: ArtifactInformation$Type;
declare class Environment$Type extends MessageType<Environment> {
    constructor();
    create(value?: PartialMessage<Environment>): Environment;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: Environment): Environment;
    private binaryReadMap7;
    internalBinaryWrite(message: Environment, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.Environment
 */
export declare const Environment: Environment$Type;
declare class StandardEnvironments$Type extends MessageType<StandardEnvironments> {
    constructor();
    create(value?: PartialMessage<StandardEnvironments>): StandardEnvironments;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: StandardEnvironments): StandardEnvironments;
    internalBinaryWrite(message: StandardEnvironments, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.StandardEnvironments
 */
export declare const StandardEnvironments: StandardEnvironments$Type;
declare class DockerPayload$Type extends MessageType<DockerPayload> {
    constructor();
    create(value?: PartialMessage<DockerPayload>): DockerPayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: DockerPayload): DockerPayload;
    internalBinaryWrite(message: DockerPayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.DockerPayload
 */
export declare const DockerPayload: DockerPayload$Type;
declare class ProcessPayload$Type extends MessageType<ProcessPayload> {
    constructor();
    create(value?: PartialMessage<ProcessPayload>): ProcessPayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ProcessPayload): ProcessPayload;
    private binaryReadMap4;
    internalBinaryWrite(message: ProcessPayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.ProcessPayload
 */
export declare const ProcessPayload: ProcessPayload$Type;
declare class ExternalPayload$Type extends MessageType<ExternalPayload> {
    constructor();
    create(value?: PartialMessage<ExternalPayload>): ExternalPayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ExternalPayload): ExternalPayload;
    private binaryReadMap2;
    internalBinaryWrite(message: ExternalPayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.ExternalPayload
 */
export declare const ExternalPayload: ExternalPayload$Type;
declare class StandardProtocols$Type extends MessageType<StandardProtocols> {
    constructor();
    create(value?: PartialMessage<StandardProtocols>): StandardProtocols;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: StandardProtocols): StandardProtocols;
    internalBinaryWrite(message: StandardProtocols, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.StandardProtocols
 */
export declare const StandardProtocols: StandardProtocols$Type;
declare class StandardRunnerProtocols$Type extends MessageType<StandardRunnerProtocols> {
    constructor();
    create(value?: PartialMessage<StandardRunnerProtocols>): StandardRunnerProtocols;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: StandardRunnerProtocols): StandardRunnerProtocols;
    internalBinaryWrite(message: StandardRunnerProtocols, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.StandardRunnerProtocols
 */
export declare const StandardRunnerProtocols: StandardRunnerProtocols$Type;
declare class StandardRequirements$Type extends MessageType<StandardRequirements> {
    constructor();
    create(value?: PartialMessage<StandardRequirements>): StandardRequirements;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: StandardRequirements): StandardRequirements;
    internalBinaryWrite(message: StandardRequirements, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.StandardRequirements
 */
export declare const StandardRequirements: StandardRequirements$Type;
declare class FunctionSpec$Type extends MessageType<FunctionSpec> {
    constructor();
    create(value?: PartialMessage<FunctionSpec>): FunctionSpec;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: FunctionSpec): FunctionSpec;
    internalBinaryWrite(message: FunctionSpec, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.FunctionSpec
 */
export declare const FunctionSpec: FunctionSpec$Type;
declare class StandardDisplayData$Type extends MessageType<StandardDisplayData> {
    constructor();
    create(value?: PartialMessage<StandardDisplayData>): StandardDisplayData;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: StandardDisplayData): StandardDisplayData;
    internalBinaryWrite(message: StandardDisplayData, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.StandardDisplayData
 */
export declare const StandardDisplayData: StandardDisplayData$Type;
declare class LabelledPayload$Type extends MessageType<LabelledPayload> {
    constructor();
    create(value?: PartialMessage<LabelledPayload>): LabelledPayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: LabelledPayload): LabelledPayload;
    internalBinaryWrite(message: LabelledPayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.LabelledPayload
 */
export declare const LabelledPayload: LabelledPayload$Type;
declare class DisplayData$Type extends MessageType<DisplayData> {
    constructor();
    create(value?: PartialMessage<DisplayData>): DisplayData;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: DisplayData): DisplayData;
    internalBinaryWrite(message: DisplayData, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.DisplayData
 */
export declare const DisplayData: DisplayData$Type;
declare class MessageWithComponents$Type extends MessageType<MessageWithComponents> {
    constructor();
    create(value?: PartialMessage<MessageWithComponents>): MessageWithComponents;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: MessageWithComponents): MessageWithComponents;
    internalBinaryWrite(message: MessageWithComponents, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.MessageWithComponents
 */
export declare const MessageWithComponents: MessageWithComponents$Type;
declare class ExecutableStagePayload$Type extends MessageType<ExecutableStagePayload> {
    constructor();
    create(value?: PartialMessage<ExecutableStagePayload>): ExecutableStagePayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ExecutableStagePayload): ExecutableStagePayload;
    internalBinaryWrite(message: ExecutableStagePayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.ExecutableStagePayload
 */
export declare const ExecutableStagePayload: ExecutableStagePayload$Type;
declare class ExecutableStagePayload_SideInputId$Type extends MessageType<ExecutableStagePayload_SideInputId> {
    constructor();
    create(value?: PartialMessage<ExecutableStagePayload_SideInputId>): ExecutableStagePayload_SideInputId;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ExecutableStagePayload_SideInputId): ExecutableStagePayload_SideInputId;
    internalBinaryWrite(message: ExecutableStagePayload_SideInputId, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.ExecutableStagePayload.SideInputId
 */
export declare const ExecutableStagePayload_SideInputId: ExecutableStagePayload_SideInputId$Type;
declare class ExecutableStagePayload_UserStateId$Type extends MessageType<ExecutableStagePayload_UserStateId> {
    constructor();
    create(value?: PartialMessage<ExecutableStagePayload_UserStateId>): ExecutableStagePayload_UserStateId;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ExecutableStagePayload_UserStateId): ExecutableStagePayload_UserStateId;
    internalBinaryWrite(message: ExecutableStagePayload_UserStateId, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.ExecutableStagePayload.UserStateId
 */
export declare const ExecutableStagePayload_UserStateId: ExecutableStagePayload_UserStateId$Type;
declare class ExecutableStagePayload_TimerId$Type extends MessageType<ExecutableStagePayload_TimerId> {
    constructor();
    create(value?: PartialMessage<ExecutableStagePayload_TimerId>): ExecutableStagePayload_TimerId;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ExecutableStagePayload_TimerId): ExecutableStagePayload_TimerId;
    internalBinaryWrite(message: ExecutableStagePayload_TimerId, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.ExecutableStagePayload.TimerId
 */
export declare const ExecutableStagePayload_TimerId: ExecutableStagePayload_TimerId$Type;
declare class ExecutableStagePayload_TimerFamilyId$Type extends MessageType<ExecutableStagePayload_TimerFamilyId> {
    constructor();
    create(value?: PartialMessage<ExecutableStagePayload_TimerFamilyId>): ExecutableStagePayload_TimerFamilyId;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ExecutableStagePayload_TimerFamilyId): ExecutableStagePayload_TimerFamilyId;
    internalBinaryWrite(message: ExecutableStagePayload_TimerFamilyId, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.ExecutableStagePayload.TimerFamilyId
 */
export declare const ExecutableStagePayload_TimerFamilyId: ExecutableStagePayload_TimerFamilyId$Type;
declare class ExecutableStagePayload_WireCoderSetting$Type extends MessageType<ExecutableStagePayload_WireCoderSetting> {
    constructor();
    create(value?: PartialMessage<ExecutableStagePayload_WireCoderSetting>): ExecutableStagePayload_WireCoderSetting;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ExecutableStagePayload_WireCoderSetting): ExecutableStagePayload_WireCoderSetting;
    internalBinaryWrite(message: ExecutableStagePayload_WireCoderSetting, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.ExecutableStagePayload.WireCoderSetting
 */
export declare const ExecutableStagePayload_WireCoderSetting: ExecutableStagePayload_WireCoderSetting$Type;
declare class StandardResourceHints$Type extends MessageType<StandardResourceHints> {
    constructor();
    create(value?: PartialMessage<StandardResourceHints>): StandardResourceHints;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: StandardResourceHints): StandardResourceHints;
    internalBinaryWrite(message: StandardResourceHints, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.StandardResourceHints
 */
export declare const StandardResourceHints: StandardResourceHints$Type;
/**
 * @generated ServiceType for protobuf service org.apache.beam.model.pipeline.v1.TestStreamService
 */
export declare const TestStreamService: ServiceType;
export {};
