import type { BinaryWriteOptions } from "@protobuf-ts/runtime";
import type { IBinaryWriter } from "@protobuf-ts/runtime";
import type { BinaryReadOptions } from "@protobuf-ts/runtime";
import type { IBinaryReader } from "@protobuf-ts/runtime";
import type { PartialMessage } from "@protobuf-ts/runtime";
import { MessageType } from "@protobuf-ts/runtime";
import { Schema } from "./schema";
/**
 * A configuration payload for an external transform.
 * Used as the payload of ExternalTransform as part of an ExpansionRequest.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.ExternalConfigurationPayload
 */
export interface ExternalConfigurationPayload {
    /**
     * A schema for use in beam:coder:row:v1
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Schema schema = 1;
     */
    schema?: Schema;
    /**
     * A payload which can be decoded using beam:coder:row:v1 and the given
     * schema.
     *
     * @generated from protobuf field: bytes payload = 2;
     */
    payload: Uint8Array;
}
/**
 * Defines specific expansion methods that may be used to expand cross-language
 * transforms.
 * Has to be set as the URN of the transform of the expansion request.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.ExpansionMethods
 */
export interface ExpansionMethods {
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.ExpansionMethods.Enum
 */
export declare enum ExpansionMethods_Enum {
    /**
     * Expand a Java transform using specified constructor and builder methods.
     * Transform payload will be of type JavaClassLookupPayload.
     *
     * @generated from protobuf enum value: JAVA_CLASS_LOOKUP = 0;
     */
    JAVA_CLASS_LOOKUP = 0
}
/**
 * A configuration payload for an external transform.
 * Used to define a Java transform that can be directly instantiated by a Java
 * expansion service.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.JavaClassLookupPayload
 */
export interface JavaClassLookupPayload {
    /**
     * Name of the Java transform class.
     *
     * @generated from protobuf field: string class_name = 1;
     */
    className: string;
    /**
     * A static method to construct the initial instance of the transform.
     * If not provided, the transform should be instantiated using a class
     * constructor.
     *
     * @generated from protobuf field: string constructor_method = 2;
     */
    constructorMethod: string;
    /**
     * The top level fields of the schema represent the method parameters in
     * order.
     * If able, top level field names are also verified against the method
     * parameters for a match.
     * Any field names in the form 'ignore[0-9]+' will not be used for validation
     * hence that format can be used to represent arbitrary field names.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Schema constructor_schema = 3;
     */
    constructorSchema?: Schema;
    /**
     * A payload which can be decoded using beam:coder:row:v1 and the provided
     * constructor schema.
     *
     * @generated from protobuf field: bytes constructor_payload = 4;
     */
    constructorPayload: Uint8Array;
    /**
     * Set of builder methods and corresponding parameters to apply after the
     * transform object is constructed.
     * When constructing the transform object, given builder methods will be
     * applied in order.
     *
     * @generated from protobuf field: repeated org.apache.beam.model.pipeline.v1.BuilderMethod builder_methods = 5;
     */
    builderMethods: BuilderMethod[];
}
/**
 * This represents a builder method of the transform class that should be
 * applied in-order after instantiating the initial transform object.
 * Each builder method may take one or more parameters and has to return an
 * instance of the transform object.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.BuilderMethod
 */
export interface BuilderMethod {
    /**
     * Name of the builder method
     *
     * @generated from protobuf field: string name = 1;
     */
    name: string;
    /**
     * The top level fields of the schema represent the method parameters in
     * order.
     * If able, top level field names are also verified against the method
     * parameters for a match.
     * Any field names in the form 'ignore[0-9]+' will not be used for validation
     * hence that format can be used to represent arbitrary field names.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Schema schema = 2;
     */
    schema?: Schema;
    /**
     * A payload which can be decoded using beam:coder:row:v1 and the builder
     * method schema.
     *
     * @generated from protobuf field: bytes payload = 3;
     */
    payload: Uint8Array;
}
declare class ExternalConfigurationPayload$Type extends MessageType<ExternalConfigurationPayload> {
    constructor();
    create(value?: PartialMessage<ExternalConfigurationPayload>): ExternalConfigurationPayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ExternalConfigurationPayload): ExternalConfigurationPayload;
    internalBinaryWrite(message: ExternalConfigurationPayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.ExternalConfigurationPayload
 */
export declare const ExternalConfigurationPayload: ExternalConfigurationPayload$Type;
declare class ExpansionMethods$Type extends MessageType<ExpansionMethods> {
    constructor();
    create(value?: PartialMessage<ExpansionMethods>): ExpansionMethods;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ExpansionMethods): ExpansionMethods;
    internalBinaryWrite(message: ExpansionMethods, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.ExpansionMethods
 */
export declare const ExpansionMethods: ExpansionMethods$Type;
declare class JavaClassLookupPayload$Type extends MessageType<JavaClassLookupPayload> {
    constructor();
    create(value?: PartialMessage<JavaClassLookupPayload>): JavaClassLookupPayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: JavaClassLookupPayload): JavaClassLookupPayload;
    internalBinaryWrite(message: JavaClassLookupPayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.JavaClassLookupPayload
 */
export declare const JavaClassLookupPayload: JavaClassLookupPayload$Type;
declare class BuilderMethod$Type extends MessageType<BuilderMethod> {
    constructor();
    create(value?: PartialMessage<BuilderMethod>): BuilderMethod;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: BuilderMethod): BuilderMethod;
    internalBinaryWrite(message: BuilderMethod, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.BuilderMethod
 */
export declare const BuilderMethod: BuilderMethod$Type;
export {};
