import * as runnerApiProto from "../../proto/beam_runner_api";
import { JobServiceClient } from "../../proto/beam_job_api.client";
import { PipelineResult, Runner } from "../runner";
import { PipelineOptions } from "../../options/pipeline_options";
import { JobState_Enum, JobStateEvent } from "../../proto/beam_job_api";
import { MonitoringInfo } from "../../proto/metrics";
import { Service as JobService } from "../../utils/service";
declare type completionCallback = (terminalState: JobStateEvent) => Promise<unknown>;
declare class PortableRunnerPipelineResult extends PipelineResult {
    jobId: string;
    runner: PortableRunner;
    completionCallbacks: completionCallback[];
    terminalState?: JobStateEvent;
    finalMetrics?: MonitoringInfo[];
    constructor(runner: PortableRunner, jobId: string, completionCallbacks: completionCallback[]);
    static isTerminal(state: JobState_Enum): boolean;
    getState(): Promise<JobStateEvent>;
    cancel(): Promise<void>;
    /**
     * Waits until the pipeline finishes and returns the final status.
     * @param duration timeout in milliseconds.
     */
    waitUntilFinish(duration?: number): Promise<JobState_Enum>;
    rawMetrics(): Promise<MonitoringInfo[]>;
}
export declare class PortableRunner extends Runner {
    private jobService;
    client?: JobServiceClient;
    defaultOptions: any;
    constructor(options: string | {
        jobEndpoint: string;
        [others: string]: any;
    }, jobService?: JobService | undefined);
    getClient(): Promise<JobServiceClient>;
    getJobMetrics(jobId: string): Promise<import("../../proto/beam_job_api").GetJobMetricsResponse>;
    getJobState(jobId: string): Promise<JobStateEvent>;
    cancelJob(jobId: string): Promise<import("../../proto/beam_job_api").CancelJobResponse>;
    runPipeline(pipeline: runnerApiProto.Pipeline, options?: PipelineOptions): Promise<PipelineResult>;
    runPipelineWithProto(pipeline: runnerApiProto.Pipeline, options?: PipelineOptions): Promise<PortableRunnerPipelineResult>;
}
export {};
