import { JobState_Enum } from "../proto/beam_job_api";
import * as runnerApi from "../proto/beam_runner_api";
import { MonitoringInfo } from "../proto/metrics";
import { Root, PValue } from "../pvalue";
import { PipelineOptions } from "../options/pipeline_options";
export declare class PipelineResult {
    waitUntilFinish(duration?: number): Promise<JobState_Enum>;
    rawMetrics(): Promise<MonitoringInfo[]>;
    counters(): Promise<{
        [key: string]: number;
    }>;
    distributions(): Promise<{
        [key: string]: number;
    }>;
}
/**
 * Creates a `Runner` object with the given set of options.
 *
 * The exact type of runner to be created can be specified by the special
 * `runner` option, e.g. `createRunner({runner: "direct"})` would create
 * a direct runner.  If no runner option is specified, the "default" runner
 * is used, which runs what pipelines it can on the direct runner, and
 * otherwise falls back to the universal runner (e.g. if cross-language
 * transforms, non-trivial windowing, etc. are used).
 */
export declare function createRunner(options?: any): Runner;
/**
 * A Runner is the object that takes a pipeline definition and actually
 * executes, e.g. locally or on a distributed system, by invoking its
 * `run` or `runAsync` method.
 *
 * Runners are generally created using the `createRunner` method in this
 * same module.
 */
export declare abstract class Runner {
    /**
     * Runs the transform.
     *
     * Resolves to an instance of PipelineResult when the pipeline completes.
     * Use runAsync() to execute the pipeline in the background.
     *
     * @param pipeline
     * @returns A PipelineResult
     */
    run(pipeline: (root: Root) => PValue<any> | Promise<PValue<any>>, options?: PipelineOptions): Promise<PipelineResult>;
    /**
     * runAsync() is the asynchronous version of run(), does not wait until
     * pipeline finishes. Use the returned PipelineResult to query job
     * status.
     */
    runAsync(pipeline: (root: Root) => PValue<any> | Promise<PValue<any>>, options?: PipelineOptions): Promise<PipelineResult>;
    abstract runPipeline(pipeline: runnerApi.Pipeline, options?: PipelineOptions): Promise<PipelineResult>;
}
export declare function defaultRunner(defaultOptions: Object): Runner;
export declare function loopbackRunner(defaultOptions?: Object): Runner;
