import * as runnerApi from "../proto/beam_runner_api";
import { PipelineOptions } from "../options/pipeline_options";
import { PValue, Root } from "../pvalue";
import { PipelineResult, Runner } from "../runners/runner";
/**
 * A Runner implementation used to turn multiple pipeline `run()`s into a
 * a single `run()` of all the pipelines in parallel.
 *
 * This is primarily useful for testing runners (e.g. distributed runners)
 * whose per-pipeline costs are substantially larger than the typical amount
 * of computation done in a single unit test.
 *
 * After invoking `run()` on several pipelines, one must invoke
 * `reallyRunPipelines()` which will actually execute the pipelines on
 * the underlying runner. Any individual pipeline failure will cause the
 * entire pipeline to fail.
 *
 * Note that due to the (doubly) deferred nature of `run()`, the test in
 * question should use transforms like `testing.assert.assertDeepEqual`
 * (which fail if the input PCollection does not have the expected contents)
 * rather than trying to validate any side effects of the (not-yet-executed)
 * pipeline directly.
 */
export declare class MultiPipelineRunner extends Runner {
    private underlying;
    private options;
    allPipelines?: runnerApi.Pipeline;
    counter: number;
    nextTestName?: string;
    usedTestNames: Set<string>;
    constructor(underlying: Runner, options?: PipelineOptions);
    setNextTestName(name: string): void;
    runAsync(pipeline: (root: Root) => PValue<any> | Promise<PValue<any>>, options?: PipelineOptions): Promise<PipelineResult>;
    runPipeline(pipeline: runnerApi.Pipeline, options?: PipelineOptions): Promise<PipelineResult>;
    reallyRunPipelines(): Promise<PipelineResult>;
    getPrefix(): string;
    mergePipeline(pipeline: runnerApi.Pipeline): void;
}
