"use strict";
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MultiPipelineRunner = void 0;
const _tct_flatten_destructured_imports_1 = __importStar(require("../proto/beam_runner_api"));
var runnerApi = _tct_flatten_destructured_imports_1;
const _tct_flatten_destructured_imports_2 = __importStar(require("../proto/beam_job_api"));
var jobApi = _tct_flatten_destructured_imports_2;
const _tct_flatten_destructured_imports_3 = __importStar(require("../transforms"));
var withName = _tct_flatten_destructured_imports_3.withName;
const _tct_flatten_destructured_imports_4 = __importStar(require("../options/pipeline_options"));
var PipelineOptions = _tct_flatten_destructured_imports_4.PipelineOptions;
const _tct_flatten_destructured_imports_5 = __importStar(require("../internal/pipeline"));
var Pipeline = _tct_flatten_destructured_imports_5.Pipeline;
const _tct_flatten_destructured_imports_6 = __importStar(require("../pvalue"));
var PValue = _tct_flatten_destructured_imports_6.PValue;
var Root = _tct_flatten_destructured_imports_6.Root;
const _tct_flatten_destructured_imports_7 = __importStar(require("../runners/runner"));
var PipelineResult = _tct_flatten_destructured_imports_7.PipelineResult;
var Runner = _tct_flatten_destructured_imports_7.Runner;
class FakePipelineResult extends PipelineResult {
    async waitUntilFinish(duration) {
        return jobApi.JobState_Enum.DONE;
    }
}
/**
 * A Runner implementation used to turn multiple pipeline `run()`s into a
 * a single `run()` of all the pipelines in parallel.
 *
 * This is primarily useful for testing runners (e.g. distributed runners)
 * whose per-pipeline costs are substantially larger than the typical amount
 * of computation done in a single unit test.
 *
 * After invoking `run()` on several pipelines, one must invoke
 * `reallyRunPipelines()` which will actually execute the pipelines on
 * the underlying runner. Any individual pipeline failure will cause the
 * entire pipeline to fail.
 *
 * Note that due to the (doubly) deferred nature of `run()`, the test in
 * question should use transforms like `testing.assert.assertDeepEqual`
 * (which fail if the input PCollection does not have the expected contents)
 * rather than trying to validate any side effects of the (not-yet-executed)
 * pipeline directly.
 */
class MultiPipelineRunner extends Runner {
    constructor(underlying, options = {}) {
        super();
        this.underlying = underlying;
        this.options = options;
        this.counter = 0;
        this.usedTestNames = new Set();
    }
    setNextTestName(name) {
        var counter = 1;
        var nextTestName = name;
        while (this.usedTestNames.has(nextTestName)) {
            counter++;
            nextTestName = name + counter;
        }
        this.nextTestName = nextTestName;
    }
    async runAsync(pipeline, options) {
        var _tct_transform_1;
        if (this.nextTestName === undefined) {
            this.setNextTestName("pipeline");
        }
        this.usedTestNames.add(this.nextTestName);
        const p = new Pipeline(this.getPrefix());
        await new Root(p).applyAsync(withName(this.nextTestName, (_tct_transform_1 = async (root) => {
            await pipeline(root);
        }, _tct_transform_1.__closure = () => ({ pipeline }), _tct_transform_1)));
        this.nextTestName = undefined;
        return this.runPipeline(p.getProto());
    }
    async runPipeline(pipeline, options) {
        if (options) {
            throw new Error("Per-pipeline options not supported.");
        }
        this.mergePipeline(pipeline);
        return new FakePipelineResult();
    }
    async reallyRunPipelines() {
        if (this.allPipelines === undefined) {
            return new FakePipelineResult();
        }
        console.log(this.allPipelines);
        const pipelineResult = await this.underlying.runPipeline(this.allPipelines, this.options);
        const finalState = await pipelineResult.waitUntilFinish();
        if (finalState != jobApi.JobState_Enum.DONE) {
            // TODO: Grab the last/most severe error message?
            throw new Error("Job finished in state " + jobApi.JobState_Enum[finalState]);
        }
        this.allPipelines = undefined;
        return pipelineResult;
    }
    getPrefix() {
        try {
            return "namespace_" + this.counter + "_";
        }
        finally {
            this.counter += 1;
        }
    }
    mergePipeline(pipeline) {
        function mergeComponents(src, dest) {
            for (const [id, proto] of Object.entries(src)) {
                if (dest[id] === undefined) {
                    dest[id] = proto;
                }
                else if (dest[id] != proto) {
                    require("assert").deepEqual(dest[id], proto);
                    throw new Error("Expected distinct components: " + id);
                }
            }
        }
        mergeComponents.__closure = () => ({ Object, require, Error });
        if (this.allPipelines === undefined) {
            this.allPipelines = runnerApi.Pipeline.create({
                components: runnerApi.Components.create({}),
            });
        }
        mergeComponents(pipeline.components?.transforms, this.allPipelines.components?.transforms);
        mergeComponents(pipeline.components?.pcollections, this.allPipelines.components?.pcollections);
        mergeComponents(pipeline.components?.coders, this.allPipelines.components?.coders);
        mergeComponents(pipeline.components?.windowingStrategies, this.allPipelines.components?.windowingStrategies);
        mergeComponents(pipeline.components?.environments, this.allPipelines.components?.environments);
        this.allPipelines.requirements = [
            ...new Set([...this.allPipelines.requirements, ...pipeline.requirements]),
        ];
        this.allPipelines.rootTransformIds = [
            ...this.allPipelines.rootTransformIds,
            ...pipeline.rootTransformIds,
        ];
    }
}
exports.MultiPipelineRunner = MultiPipelineRunner;
//# sourceMappingURL=multi_pipeline_runner.js.map