"use strict";
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
/**
 * `Impulse` is the basic *source* primitive `PTransformClass`. It receives a Beam
 * Root as input, and returns a `PCollection` of `Uint8Array` with a single
 * element with length=0 (i.e. the empty byte array: `new Uint8Array("")`).
 *
 * `Impulse` is used to start the execution of a pipeline with a single element
 * that can trigger execution of a source or SDF.
 */
function impulse() {
    function expandInternal(input, pipeline, transformProto) {
        transformProto.spec = runnerApi.FunctionSpec.create({
            urn: impulse.urn,
            payload: urns.IMPULSE_BUFFER,
        });
        transformProto.environmentId = "";
        return pipeline.createPCollectionInternal(new BytesCoder());
    }
    expandInternal.__closure = () => ({ runnerApi, impulse, urns, BytesCoder });
    return withName("impulse", expandInternal);
}
var _tct_transform_1, _tct_transform_2;
impulse.__closure = () => ({ runnerApi, urns, BytesCoder, withName });
// TODO: (API) Should we offer a method on PCollection to do this?
function withCoderInternal(coder) {
    return withName(`withCoderInternal(${extractName(coder)})`, (_tct_transform_1 = (input, pipeline, transformProto) => {
        // IDENTITY rather than Flatten for better fusion.
        transformProto.spec = {
            urn: parDo.urn,
            payload: runnerApi.ParDoPayload.toBinary(runnerApi.ParDoPayload.create({
                doFn: runnerApi.FunctionSpec.create({
                    urn: urns.IDENTITY_DOFN_URN,
                    payload: undefined,
                }),
            })),
        };
        return pipeline.createPCollectionInternal(coder);
    }, _tct_transform_1.__closure = () => ({ parDo, runnerApi, urns, coder }), _tct_transform_1));
}
withCoderInternal.__closure = () => ({ withName, extractName, parDo, runnerApi, urns });
/**
 * Returns a PTransform returning a PCollection with the same contents as the
 * input PCollection, but with the given Row (aka Schema'd) Coder, based on
 * an "example" element. E.g.
 *
 *```js
 * const unknown_schema_pcoll = ...
 * const schema_pcoll = unknown_schema_pcoll.apply(
 *     withRowCoder({int_field: 0, str_field: ""}));
 *```
 *
 * This is particularly useful for declaring the type of the PCollection to
 * invoke cross-language transforms.
 */
function withRowCoder(exemplar) {
    return withCoderInternal(RowCoder.fromJSON(exemplar));
}
withRowCoder.__closure = () => ({ withCoderInternal, RowCoder });
/**
 * **Note**: Users should not be using `GroupByKey` transforms directly. Use instead
 * `GroupBy`, and `Combine` transforms.
 *
 * `GroupByKey` is the primitive transform in Beam to force *shuffling* of data,
 * which helps us group data of the same key together. It's a necessary primitive
 * for any Beam SDK.
 *
 * `GroupByKey` operations are used under the hood to execute combines,
 * streaming triggers, stateful transforms, etc.
 */
function groupByKey() {
    function expandInternal(input, pipeline, transformProto) {
        const pipelineComponents = pipeline.getProto().components;
        const inputCoderProto = pipelineComponents.coders[pipelineComponents.pcollections[input.getId()].coderId];
        if (inputCoderProto.spec.urn !== KVCoder.URN) {
            return input
                .apply(withCoderInternal(new KVCoder(new GeneralObjectCoder(), new GeneralObjectCoder())))
                .apply(groupByKey());
        }
        transformProto.spec = runnerApi.FunctionSpec.create({
            urn: groupByKey.urn,
            payload: undefined,
        });
        transformProto.environmentId = "";
        // TODO: (Cleanup) warn about BsonObjectCoder and (non)deterministic key ordering?
        const keyCoder = pipeline.getCoder(inputCoderProto.componentCoderIds[0]);
        const valueCoder = pipeline.getCoder(inputCoderProto.componentCoderIds[1]);
        const iterableValueCoder = new IterableCoder(valueCoder);
        const outputCoder = new KVCoder(keyCoder, iterableValueCoder);
        return pipeline.createPCollectionInternal(outputCoder);
    }
    expandInternal.__closure = () => ({ KVCoder, withCoderInternal, GeneralObjectCoder, groupByKey, runnerApi, IterableCoder });
    return withName("groupByKey", expandInternal);
}
groupByKey.__closure = () => ({ KVCoder, withCoderInternal, GeneralObjectCoder, runnerApi, IterableCoder, withName });
/**
 * This transform is used to perform aggregations over groups of elements.
 *
 * It receives a `CombineFn`, which defines functions to create an intermediate
 * aggregator, add elements to it, and transform the aggregator into the expected
 * output.
 *
 * Combines are a valuable transform because they allow for optimizations that
 * can reduce the amount of data being exchanged between workers
 * (a.k.a. "shuffled"). They do this by performing partial aggregations
 * before a `GroupByKey` and after the `GroupByKey`. The partial aggregations
 * help reduce the original data into a single aggregator per key per worker.
 */
function combinePerKey(combineFn) {
    function expandInternal(input, pipeline, transformProto) {
        const pipelineComponents = pipeline.getProto().components;
        const inputProto = pipelineComponents.pcollections[input.getId()];
        try {
            // If this fails, we cannot lift, so we skip setting the liftable URN.
            CombinePerKeyPrecombineOperator.checkSupportsWindowing(pipelineComponents.windowingStrategies[inputProto.windowingStrategyId]);
            // Ensure the input is using the KV coder.
            const inputCoderProto = pipelineComponents.coders[inputProto.coderId];
            if (inputCoderProto.spec.urn !== KVCoder.URN) {
                return input
                    .apply(withCoderInternal(new KVCoder(new GeneralObjectCoder(), new GeneralObjectCoder())))
                    .apply(combinePerKey(combineFn));
            }
            const inputValueCoder = pipeline.context.getCoder(inputCoderProto.componentCoderIds[1]);
            transformProto.spec = runnerApi.FunctionSpec.create({
                urn: combinePerKey.urn,
                payload: runnerApi.CombinePayload.toBinary({
                    combineFn: {
                        urn: urns.SERIALIZED_JS_COMBINEFN_INFO,
                        payload: serializeFn({ combineFn }),
                    },
                    accumulatorCoderId: pipeline.context.getCoderId(combineFn.accumulatorCoder
                        ? combineFn.accumulatorCoder(inputValueCoder)
                        : new GeneralObjectCoder()),
                }),
            });
        }
        catch (err) {
            // Execute this as an unlifted combine.
        }
        return input //
            .apply(groupByKey())
            .map(withName("applyCombine", (_tct_transform_2 = (kv) => {
            // Artificially use multiple accumulators to emulate what would
            // happen in a distributed combine for better testing.
            const accumulators = [
                combineFn.createAccumulator(),
                combineFn.createAccumulator(),
                combineFn.createAccumulator(),
            ];
            let ix = 0;
            for (const value of kv.value) {
                accumulators[ix % 3] = combineFn.addInput(accumulators[ix % 3], value);
            }
            return {
                key: kv.key,
                value: combineFn.extractOutput(combineFn.mergeAccumulators(accumulators)),
            };
        }, _tct_transform_2.__closure = () => ({ combineFn }), _tct_transform_2)));
    }
    expandInternal.__closure = () => ({ CombinePerKeyPrecombineOperator, KVCoder, withCoderInternal, GeneralObjectCoder, combinePerKey, combineFn, runnerApi, urns, serializeFn, groupByKey, withName });
    return withName(`combinePerKey(${extractName(combineFn)})`, expandInternal);
}
combinePerKey.__closure = () => ({ CombinePerKeyPrecombineOperator, KVCoder, withCoderInternal, GeneralObjectCoder, runnerApi, urns, serializeFn, groupByKey, withName, extractName });
Object.defineProperty(exports, "__esModule", { value: true });
exports.combinePerKey = exports.groupByKey = exports.withRowCoder = exports.withCoderInternal = exports.impulse = void 0;
const _tct_flatten_destructured_imports_1 = __importStar(require("../proto/beam_runner_api"));
var runnerApi = _tct_flatten_destructured_imports_1;
const _tct_flatten_destructured_imports_2 = __importStar(require("../internal/urns"));
var urns = _tct_flatten_destructured_imports_2;
const _tct_flatten_destructured_imports_3 = __importStar(require("./transform"));
var PTransform = _tct_flatten_destructured_imports_3.PTransform;
var PTransformClass = _tct_flatten_destructured_imports_3.PTransformClass;
var withName = _tct_flatten_destructured_imports_3.withName;
var extractName = _tct_flatten_destructured_imports_3.extractName;
const _tct_flatten_destructured_imports_4 = __importStar(require("../pvalue"));
var PCollection = _tct_flatten_destructured_imports_4.PCollection;
var Root = _tct_flatten_destructured_imports_4.Root;
const _tct_flatten_destructured_imports_5 = __importStar(require("../internal/pipeline"));
var Pipeline = _tct_flatten_destructured_imports_5.Pipeline;
const _tct_flatten_destructured_imports_6 = __importStar(require("../coders/coders"));
var Coder = _tct_flatten_destructured_imports_6.Coder;
const _tct_flatten_destructured_imports_7 = __importStar(require("../coders/required_coders"));
var BytesCoder = _tct_flatten_destructured_imports_7.BytesCoder;
var KVCoder = _tct_flatten_destructured_imports_7.KVCoder;
var IterableCoder = _tct_flatten_destructured_imports_7.IterableCoder;
const _tct_flatten_destructured_imports_8 = __importStar(require("./pardo"));
var parDo = _tct_flatten_destructured_imports_8.parDo;
const _tct_flatten_destructured_imports_9 = __importStar(require("../coders/js_coders"));
var GeneralObjectCoder = _tct_flatten_destructured_imports_9.GeneralObjectCoder;
const _tct_flatten_destructured_imports_10 = __importStar(require("../coders/row_coder"));
var RowCoder = _tct_flatten_destructured_imports_10.RowCoder;
const _tct_flatten_destructured_imports_11 = __importStar(require("../values"));
var KV = _tct_flatten_destructured_imports_11.KV;
const _tct_flatten_destructured_imports_12 = __importStar(require("./group_and_combine"));
var CombineFn = _tct_flatten_destructured_imports_12.CombineFn;
const _tct_flatten_destructured_imports_13 = __importStar(require("../internal/serialize"));
var serializeFn = _tct_flatten_destructured_imports_13.serializeFn;
const _tct_flatten_destructured_imports_14 = __importStar(require("../worker/operators"));
var CombinePerKeyPrecombineOperator = _tct_flatten_destructured_imports_14.CombinePerKeyPrecombineOperator;
exports.impulse = impulse;
impulse.urn = "beam:transform:impulse:v1";
exports.withCoderInternal = withCoderInternal;
exports.withRowCoder = withRowCoder;
exports.groupByKey = groupByKey;
// TODO: (Cleanup) runnerApi.StandardPTransformClasss_Primitives.GROUP_BY_KEY.urn.
groupByKey.urn = "beam:transform:group_by_key:v1";
exports.combinePerKey = combinePerKey;
combinePerKey.urn = "beam:transform:combine_per_key:v1";
//# sourceMappingURL=internal.js.map