"use strict";
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
/**
 * Returns a PTransform applying a Python transform (typically identified by
 * fully qualified name) to a PCollection, e.g.
 *
 *```js
 * const input_pcoll = ...
 * const output_pcoll = input_pcoll.apply(
 *     pythonTransform("beam.Map", [pythonCallable("str.upper")]));
 *```
 * See also https://beam.apache.org/documentation/programming-guide/#1324-using-cross-language-transforms-in-a-typescript-pipeline
 */
function pythonTransform(constructor, args_or_kwargs = undefined, kwargs = undefined, options = {}) {
    let args;
    if (args_or_kwargs === undefined) {
        args = [];
    }
    else if (Array.isArray(args_or_kwargs)) {
        args = args_or_kwargs;
    }
    else {
        if (kwargs != undefined) {
            throw new Error("Keyword arguments cannot be specified twice.");
        }
        args = [];
        kwargs = args_or_kwargs;
    }
    if (kwargs === undefined) {
        kwargs = {};
    }
    return external.rawExternalTransform("beam:transforms:python:fully_qualified_named", {
        constructor: constructor,
        args: Object.fromEntries(args.map((arg, ix) => ["arg" + ix, arg])),
        kwargs,
    }, (_tct_transform_1 = 
    //     "localhost:4444"
    async () => PythonService.forModule("apache_beam.runners.portability.expansion_service_main", ["--fully_qualified_name_glob=*", "--port", "{{PORT}}"]), _tct_transform_1.__closure = () => ({ PythonService }), _tct_transform_1), options);
}
var _tct_transform_1, _tct_transform_2;
pythonTransform.__closure = () => ({ Array, Error, external, Object, PythonService });
/**
 * A type representing a Python callable as a string.
 *
 * Supported formats include fully-qualified names such as `math.sin`,
 * expressions such as `lambda x: x * x` or `str.upper`, and multi-line function
 * definitions such as `def foo(x): ...` or class definitions like
 * `class Foo(...): ...`. If the source string contains multiple lines then lines
 * prior to the last will be evaluated to provide the context in which to
 * evaluate the expression, for example::
 *```py
 *    import math
 *
 *    lambda x: x - math.sin(x)
 *```
 * is a valid chunk of source code.
 */
function pythonCallable(expr) {
    return { expr, beamLogicalType: "beam:logical_type:python_callable:v1" };
}
Object.defineProperty(exports, "__esModule", { value: true });
exports.pythonCallable = exports.pythonTransform = void 0;
/**
 * Utilities for invoking Python transforms on PCollections.
 *
 * See also https://beam.apache.org/documentation/programming-guide/#1324-using-cross-language-transforms-in-a-typescript-pipeline
 *
 * @packageDocumentation
 */
const _tct_flatten_destructured_imports_1 = __importStar(require("../../apache_beam"));
var beam = _tct_flatten_destructured_imports_1;
const _tct_flatten_destructured_imports_2 = __importStar(require("../coders/standard_coders"));
var StrUtf8Coder = _tct_flatten_destructured_imports_2.StrUtf8Coder;
const _tct_flatten_destructured_imports_3 = __importStar(require("../transforms/external"));
var external = _tct_flatten_destructured_imports_3;
const _tct_flatten_destructured_imports_4 = __importStar(require("../utils/service"));
var PythonService = _tct_flatten_destructured_imports_4.PythonService;
const _tct_flatten_destructured_imports_5 = __importStar(require("../coders/row_coder"));
var row_coder = _tct_flatten_destructured_imports_5;
exports.pythonTransform = pythonTransform;
exports.pythonCallable = pythonCallable;
row_coder.registerLogicalType({
    urn: "beam:logical_type:python_callable:v1",
    reprType: row_coder.RowCoder.inferTypeFromJSON("string", false),
    toRepr: (pc) => pc.expr,
    fromRepr: (_tct_transform_2 = (expr) => pythonCallable(expr), _tct_transform_2.__closure = () => ({ pythonCallable }), _tct_transform_2),
});
//# sourceMappingURL=python.js.map