import { PTransform } from "../proto/beam_runner_api";
import * as runnerApi from "../proto/beam_runner_api";
import * as fnApi from "../proto/beam_fn_api";
import { ProcessBundleDescriptor } from "../proto/beam_fn_api";
import { MultiplexingDataChannel } from "./data";
import { MetricsContainer } from "./metrics";
import { LoggingStageInfo } from "./logging";
import { StateProvider } from "./state";
import { PipelineContext } from "../internal/pipeline";
import { Coder } from "../coders/coders";
import { Window, WindowedValue } from "../values";
import { CombineFn } from "../transforms/group_and_combine";
export declare const NonPromise: null;
export declare type ProcessResult = null | Promise<void>;
export declare class ProcessResultBuilder {
    promises: Promise<void>[];
    add(result: ProcessResult): void;
    build(): ProcessResult;
}
export interface IOperator {
    transformId: string;
    startBundle: () => Promise<void>;
    process: (wv: WindowedValue<unknown>) => ProcessResult;
    finishBundle: () => Promise<void>;
}
export declare class Receiver {
    private operators;
    private loggingStageInfo;
    private elementCounter;
    constructor(operators: IOperator[], loggingStageInfo: LoggingStageInfo, elementCounter: {
        update: (number: any) => void;
    });
    receive(wvalue: WindowedValue<unknown>): ProcessResult;
}
export declare class OperatorContext {
    descriptor: ProcessBundleDescriptor;
    getReceiver: (string: any) => Receiver;
    getDataChannel: (string: any) => MultiplexingDataChannel;
    getStateProvider: () => StateProvider;
    getBundleId: () => string;
    loggingStageInfo: LoggingStageInfo;
    metricsContainer: MetricsContainer;
    pipelineContext: PipelineContext;
    constructor(descriptor: ProcessBundleDescriptor, getReceiver: (string: any) => Receiver, getDataChannel: (string: any) => MultiplexingDataChannel, getStateProvider: () => StateProvider, getBundleId: () => string, loggingStageInfo: LoggingStageInfo, metricsContainer: MetricsContainer);
}
export declare function createOperator(transformId: string, context: OperatorContext): IOperator;
declare type OperatorConstructor = (transformId: string, transformProto: PTransform, context: OperatorContext) => IOperator;
interface OperatorClass {
    new (transformId: string, transformProto: PTransform, context: OperatorContext): IOperator;
}
export declare function registerOperator(urn: string, cls: OperatorClass): void;
export declare function registerOperatorConstructor(urn: string, constructor: OperatorConstructor): void;
export declare class DataSourceOperator implements IOperator {
    transformId: string;
    getBundleId: () => string;
    multiplexingDataChannel: MultiplexingDataChannel;
    receiver: Receiver;
    coder: Coder<WindowedValue<unknown>>;
    endOfData: Promise<void>;
    loggingStageInfo: LoggingStageInfo;
    started: boolean;
    lastProcessedElement: number;
    lastToProcessElement: number;
    constructor(transformId: string, transform: PTransform, context: OperatorContext);
    startBundle(): Promise<void>;
    process(wvalue: WindowedValue<unknown>): ProcessResult;
    split(desiredSplit: fnApi.ProcessBundleSplitRequest_DesiredSplit): fnApi.ProcessBundleSplitResponse_ChannelSplit | undefined;
    finishBundle(): Promise<void>;
}
declare abstract class CombineOperator<I, A, O> {
    transformId: string;
    receiver: Receiver;
    combineFn: CombineFn<I, A, O>;
    constructor(transformId: string, transform: PTransform, context: OperatorContext);
}
export declare class CombinePerKeyPrecombineOperator<I, A, O> extends CombineOperator<I, A, O> implements IOperator {
    keyCoder: Coder<unknown>;
    windowCoder: Coder<Window>;
    groups: Map<string, A>;
    maxKeys: number;
    static checkSupportsWindowing(windowingStrategy: runnerApi.WindowingStrategy): void;
    constructor(transformId: string, transform: PTransform, context: OperatorContext);
    process(wvalue: WindowedValue<any>): ProcessResult;
    startBundle(): Promise<void>;
    flush(target: number): ProcessResult;
    finishBundle(): Promise<void>;
}
export declare function encodeToBase64<T>(element: T, coder: Coder<T>): string;
export declare function decodeFromBase64<T>(s: string, coder: Coder<T>): T;
export {};
