import * as runnerApi from "../proto/beam_runner_api";
import * as fnApi from "../proto/beam_fn_api";
import { MetricsContainer } from "./metrics";
import { StateProvider } from "./state";
import { Coder } from "../coders/coders";
import { Window, WindowedValue } from "../values";
import { ParamProvider, SideInputParam } from "../transforms/pardo";
import * as operators from "./operators";
/**
 * @fileoverview This is where we handle the magic of populating the context
 * properties for Maps and ParDos. It is rather javascript-specific, both
 * in the way the contexts are manipulated and in the finagling we have to
 * because there is no blocking way to interact with the runner to look up
 * things like side inputs.
 */
export declare class ParamProviderImpl implements ParamProvider {
    private transformId;
    private sideInputInfo;
    private getStateProvider;
    private metricsContainer;
    wvalue: WindowedValue<unknown> | undefined;
    prefetchCallbacks: ((window: Window) => operators.ProcessResult)[];
    sideInputValues: Map<string, unknown>;
    constructor(transformId: string, sideInputInfo: Map<string, SideInputInfo>, getStateProvider: () => StateProvider, metricsContainer: MetricsContainer);
    augmentContext(context: any): any;
    prefetchSideInput(param: SideInputParam<unknown, unknown, unknown>): (window: Window) => operators.ProcessResult;
    setCurrentValue(wvalue: WindowedValue<unknown> | undefined): operators.ProcessResult;
    lookup(param: any): any;
    update(param: any, value: any): void;
}
export interface SideInputInfo {
    elementCoder: Coder<unknown>;
    windowCoder: Coder<Window>;
    windowMappingFn: (window: Window) => Window;
}
export declare function createSideInputInfo(transformProto: runnerApi.PTransform, spec: runnerApi.ParDoPayload, operatorContext: operators.OperatorContext): Map<string, SideInputInfo>;
export declare function createStateKey(transformId: string, accessPattern: string, sideInputId: string, window: Window, windowCoder: Coder<Window>): fnApi.StateKey;
