import * as grpc from "@grpc/grpc-js";
import * as fnApi from "../proto/beam_fn_api";
import { BeamFnStateClient } from "../proto/beam_fn_api.grpc-client";
interface PromiseWrapper<T> {
    type: "promise";
    promise: Promise<T>;
}
interface ValueWrapper<T> {
    type: "value";
    value: T;
}
export declare type MaybePromise<T> = PromiseWrapper<T> | ValueWrapper<T>;
export interface StateProvider {
    getState: <T>(stateKey: fnApi.StateKey, decode: (data: Uint8Array) => T) => MaybePromise<T>;
}
export declare class CachingStateProvider implements StateProvider {
    underlying: StateProvider;
    cache: Map<string, MaybePromise<any>>;
    constructor(underlying: StateProvider);
    getState<T>(stateKey: fnApi.StateKey, decode: (data: Uint8Array) => T): PromiseWrapper<any> | ValueWrapper<any>;
}
export declare class GrpcStateProvider implements StateProvider {
    private multiplexingChannel;
    private instructionId;
    constructor(multiplexingChannel: MultiplexingStateChannel, instructionId: any);
    getState<T>(stateKey: fnApi.StateKey, decode: (data: Uint8Array) => T): MaybePromise<T>;
}
/**
 * This class manages a single state channel that can be shared across multiple
 * bundles.
 *
 * Per the Beam state protocol [link], every state request is tagged with a
 * unique id which is then part of the (possibly out of order) response.
 * We model that by registering callbacks associated with each id that
 * resolve the corresponding promise that was created when the request was sent.
 */
export declare class MultiplexingStateChannel {
    stateClient: BeamFnStateClient;
    stateChannel: grpc.ClientDuplexStream<fnApi.StateRequest, fnApi.StateResponse>;
    callbacks: Map<string, (response: fnApi.StateResponse) => void>;
    closed: boolean;
    error?: Error;
    idCounter: number;
    constructor(endpoint: string, workerId: string);
    close(): void;
    getState<T>(instructionId: string, stateKey: fnApi.StateKey, decode: (data: Uint8Array) => T): MaybePromise<T>;
}
export declare function Uint8ArrayConcat(chunks: Uint8Array[]): Uint8Array;
export {};
