import * as grpc from "@grpc/grpc-js";
import { InstructionRequest, InstructionResponse } from "../proto/beam_fn_api";
import { ProcessBundleDescriptor, ProcessBundleSplitRequest, ProcessBundleSplitResponse } from "../proto/beam_fn_api";
import { BeamFnControlClient } from "../proto/beam_fn_api.grpc-client";
import { MultiplexingDataChannel } from "./data";
import { LoggingStageInfo } from "./logging";
import { MetricsContainer, MetricsShortIdCache } from "./metrics";
import { MultiplexingStateChannel, StateProvider } from "./state";
import { IOperator, Receiver } from "./operators";
export interface WorkerEndpoints {
    controlUrl: string;
}
export declare class Worker {
    private id;
    private endpoints;
    controlClient: BeamFnControlClient;
    controlChannel: grpc.ClientDuplexStream<InstructionResponse, InstructionRequest>;
    processBundleDescriptors: Map<string, ProcessBundleDescriptor>;
    bundleProcessors: Map<string, BundleProcessor[]>;
    activeBundleProcessors: Map<string, BundleProcessor>;
    dataChannels: Map<string, MultiplexingDataChannel>;
    stateChannels: Map<string, MultiplexingStateChannel>;
    metricsShortIdCache: MetricsShortIdCache;
    constructor(id: string, endpoints: WorkerEndpoints, options?: Object);
    wait(): Promise<void>;
    handleRequest(request: any): Promise<boolean | void>;
    respond(response: InstructionResponse): Promise<boolean>;
    progress(request: any): Promise<InstructionResponse>;
    split(request: any): Promise<InstructionResponse>;
    process(request: any): Promise<void>;
    aquireBundleProcessor(descriptorId: string): BundleProcessor;
    returnBundleProcessor(processor: BundleProcessor): void;
    getDataChannel(endpoint: string): MultiplexingDataChannel;
    getStateChannel(endpoint: string): MultiplexingStateChannel;
    stop(): void;
}
export declare class BundleProcessor {
    descriptor: ProcessBundleDescriptor;
    topologicallyOrderedOperators: IOperator[];
    operators: Map<string, IOperator>;
    receivers: Map<string, Receiver>;
    getDataChannel: (string: any) => MultiplexingDataChannel;
    getStateChannel: ((string: any) => MultiplexingStateChannel) | StateProvider;
    currentBundleId?: string;
    stateProvider?: StateProvider;
    loggingStageInfo: LoggingStageInfo;
    metricsContainer: MetricsContainer;
    constructor(descriptor: ProcessBundleDescriptor, getDataChannel: (string: any) => MultiplexingDataChannel, getStateChannel: ((string: any) => MultiplexingStateChannel) | StateProvider, root_urns?: string[]);
    getStateProvider(): StateProvider;
    getBundleId(): string;
    process(instructionId: string): Promise<void>;
    split(splitRequest: ProcessBundleSplitRequest): ProcessBundleSplitResponse;
    monitoringData(shortIdCache: MetricsShortIdCache): Map<string, Uint8Array>;
}
export declare const primitiveSinks: string[];
